#include "AlGaAsSb.h"
//------------------------------------------------------------------------------
double AlGaAsSb::a(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, AlSb, GaAs i GaSb";
	}
	return ( mAl*mAs*mAlAs.a(iT) + mAl*mSb*mAlSb.a(iT) + mGa*mAs*mGaAs.a(iT) + mGa*mSb*mGaSb.a(iT) );
}
//------------------------------------------------------------------------------
double AlGaAsSb::Eg(double iT, char iPoint, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, AlSb, GaAs i GaSb";
	}
	double tEgLin = mAl*mAs*mAlAs.Eg(iT, iPoint) + mAl*mSb*mAlSb.Eg(iT, iPoint) + mGa*mAs*mGaAs.Eg(iT, iPoint) + mGa*mSb*mGaSb.Eg(iT, iPoint);
	if (mInt == "lin") // interpolacja liniowa
		return ( tEgLin );
	else if (mInt == "nlin1") // interpolacja nieliniowa prosta
	{
		if (iPoint == 'G') return ( tEgLin - mAl*mGa*mAs*(-0.127+1.310*mAl) - mAl*mGa*mSb*(-0.044+1.22*mAl) - mAl*mAs*mSb*0.8 - mGa*mAs*mSb*1.43 - mAl*mGa*mAs*mSb*0.48 );
		else if (iPoint == 'X') return ( tEgLin - mAl*mGa*mAs*0.055 /*- mAl*mGa*mSb*0.*/ - mAl*mAs*mSb*0.28 - mGa*mAs*mSb*1.2 );
		else if (iPoint == 'L') return ( tEgLin /*- mAl*mGa*mAs*0.*/ /*- mAl*mGa*mSb*0.*/ - mAl*mAs*mSb*0.28 - mGa*mAs*mSb*1.2 );
		else return 0.;
	}
	else if (mInt == "nlin2") // interpolacja nieliniowa zlozona
	{
		if (iPoint == 'G')
		{
			double tEgAlGaAs = mAl * mAlAs.Eg(iT,iPoint) + mGa * mGaAs.Eg(iT,iPoint) - mAl * mGa * (-0.127+1.310*mAl);
			double tEgAlGaSb = mAl * mAlSb.Eg(iT,iPoint) + mGa * mGaSb.Eg(iT,iPoint) - mAl * mGa * (-0.044+1.22*mAl);
			double tEgAlAsSb = mAs * mAlAs.Eg(iT,iPoint) + mSb * mAlSb.Eg(iT,iPoint) - mAs * mSb * 0.8;
			double tEgGaAsSb = mAs * mGaAs.Eg(iT,iPoint) + mSb * mGaSb.Eg(iT,iPoint) - mAs * mSb * 1.43;
			return ( (mAl*mGa*(mAs*tEgAlGaAs+mSb*tEgAlGaSb-mAs*mSb*0.48) + (mAs*mSb*(mAl*tEgAlAsSb+mGa*tEgGaAsSb-mAl*mGa*0.48))) / (mAl*mGa+mAs*mSb) );
		}
		else if (iPoint == 'X')
		{
			double tEgAlGaAs = mAl * mAlAs.Eg(iT,iPoint) + mGa * mGaAs.Eg(iT,iPoint) - mAl * mGa * 0.055;
			double tEgAlGaSb = mAl * mAlSb.Eg(iT,iPoint) + mGa * mGaSb.Eg(iT,iPoint) /*- mAl * mGa * 0.*/;
			double tEgAlAsSb = mAs * mAlAs.Eg(iT,iPoint) + mSb * mAlSb.Eg(iT,iPoint) - mAs * mSb * 0.28;
			double tEgGaAsSb = mAs * mGaAs.Eg(iT,iPoint) + mSb * mGaSb.Eg(iT,iPoint) - mAs * mSb * 1.2;
			return ( (mAl*mGa*(mAs*tEgAlGaAs+mSb*tEgAlGaSb) + (mAs*mSb*(mAl*tEgAlAsSb+mGa*tEgGaAsSb))) / (mAl*mGa+mAs*mSb) );
		}
		else if (iPoint == 'L')
		{
			double tEgAlGaAs = mAl * mAlAs.Eg(iT,iPoint) + mGa * mGaAs.Eg(iT,iPoint) /*- mAl * mGa * 0.*/;
			double tEgAlGaSb = mAl * mAlSb.Eg(iT,iPoint) + mGa * mGaSb.Eg(iT,iPoint) /*- mAl * mGa * 0.*/;
			double tEgAlAsSb = mAs * mAlAs.Eg(iT,iPoint) + mSb * mAlSb.Eg(iT,iPoint) - mAs * mSb * 0.28;
			double tEgGaAsSb = mAs * mGaAs.Eg(iT,iPoint) + mSb * mGaSb.Eg(iT,iPoint) - mAs * mSb * 1.2;
			return ( (mAl*mGa*(mAs*tEgAlGaAs+mSb*tEgAlGaSb) + (mAs*mSb*(mAl*tEgAlAsSb+mGa*tEgGaAsSb))) / (mAl*mGa+mAs*mSb) );
		}
		else return 0.;
	}
	else return 0.;
}
//------------------------------------------------------------------------------
double AlGaAsSb::Eg(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, AlSb, GaAs i GaSb";
	}
	double tEgG = Eg(iT, 'G');
	double tEgX = Eg(iT, 'X');
	double tEgL = Eg(iT, 'L');
	if ((tEgG <= tEgX) && (tEgG <= tEgL)) return tEgG;
	else if (tEgX <= tEgL) return tEgX;
	else return tEgL;
}
//------------------------------------------------------------------------------
double AlGaAsSb::Dso(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, AlSb, GaAs i GaSb";
	}
	double tDsoLin = mAl*mAs*mAlAs.Dso() + mAl*mSb*mAlSb.Dso() + mGa*mAs*mGaAs.Dso() + mGa*mSb*mGaSb.Dso();
	if (mInt == "lin") // interpolacja liniowa
		return ( tDsoLin );
	else if (mInt == "nlin1") // interpolacja nieliniowa prosta
		return ( tDsoLin /*- mAl*mGa*mAs*0.*/ - mAl*mGa*mSb*0.3 - mAl*mAs*mSb*0.15 - mGa*mAs*mSb*0.6 );
	else if (mInt == "nlin2") // interpolacja nieliniowa zlozona
	{
		double tDsoAlGaAs = mAl * mAlAs.Dso() + mGa * mGaAs.Dso() /*- mAl * mGa * 0.*/;
		double tDsoAlGaSb = mAl * mAlSb.Dso() + mGa * mGaSb.Dso() - mAl * mGa * 0.3;
		double tDsoAlAsSb = mAs * mAlAs.Dso() + mSb * mAlSb.Dso() - mAs * mSb * 0.15;
		double tDsoGaAsSb = mAs * mGaAs.Dso() + mSb * mGaSb.Dso() - mAs * mSb * 0.6;
		return ( (mAl*mGa*(mAs*tDsoAlGaAs+mSb*tDsoAlGaSb) + (mAs*mSb*(mAl*tDsoAlAsSb+mGa*tDsoGaAsSb))) / (mAl*mGa+mAs*mSb) );
	}
	else return 0.;
}
//------------------------------------------------------------------------------
double AlGaAsSb::me(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, AlSb, GaAs i GaSb";
	}
	double tmeLin = mAl*mAs*mAlAs.me() + mAl*mSb*mAlSb.me() + mGa*mAs*mGaAs.me() + mGa*mSb*mGaSb.me();
	if (mInt == "lin") // interpolacja liniowa
		return ( tmeLin );
	else if (mInt == "nlin1") // interpolacja nieliniowa prosta
		return ( tmeLin /*- mAl*mGa*mAs*0.*/ /*- mAl*mGa*mSb*0.*/ /*- mAl*mAs*mSb*0.*/ - mGa*mAs*mSb*0.014 );
	else if (mInt == "nlin2") // interpolacja nieliniowa zlozona
	{
		double tmeAlGaAs = mAl * mAlAs.me() + mGa * mGaAs.me() /*- mAl * mGa * 0.*/;
		double tmeAlGaSb = mAl * mAlSb.me() + mGa * mGaSb.me() /*- mAl * mGa * 0.*/;
		double tmeAlAsSb = mAs * mAlAs.me() + mSb * mAlSb.me() /*- mAs * mSb * 0.*/;
		double tmeGaAsSb = mAs * mGaAs.me() + mSb * mGaSb.me() - mAs * mSb * 0.014;
		return ( (mAl*mGa*(mAs*tmeAlGaAs+mSb*tmeAlGaSb) + (mAs*mSb*(mAl*tmeAlAsSb+mGa*tmeGaAsSb))) / (mAl*mGa+mAs*mSb) );
	}
	else return 0.;
}
//------------------------------------------------------------------------------
double AlGaAsSb::mhh(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, AlSb, GaAs i GaSb";
	}
	double tmhhLin = mAl*mAs*mAlAs.mhh() + mAl*mSb*mAlSb.mhh() + mGa*mAs*mGaAs.mhh() + mGa*mSb*mGaSb.mhh();
	return ( tmhhLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double AlGaAsSb::mlh(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, AlSb, GaAs i GaSb";
	}
	double tmlhLin = mAl*mAs*mAlAs.mlh() + mAl*mSb*mAlSb.mlh() + mGa*mAs*mGaAs.mlh() + mGa*mSb*mGaSb.mlh();
	return ( tmlhLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double AlGaAsSb::mso(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, AlSb, GaAs i GaSb";
	}
	double tmsoLin = mAl*mAs*mAlAs.mso() + mAl*mSb*mAlSb.mso() + mGa*mAs*mGaAs.mso() + mGa*mSb*mGaSb.mso();
	return ( tmsoLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double AlGaAsSb::mh(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "mh = (mlh^3/2+mhh^3/2)^2/3";
	}
	return ( pow(pow(mlh(), 1.5) + pow(mhh(), 1.5), 2./3.) );
}
//------------------------------------------------------------------------------
double AlGaAsSb::Ev(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, AlSb, GaAs i GaSb";
	}
	double tEvLin = mAl*mAs*mAlAs.Ev() + mAl*mSb*mAlSb.Ev() + mGa*mAs*mGaAs.Ev() + mGa*mSb*mGaSb.Ev();
	if (mInt == "lin") // interpolacja liniowa
		return ( tEvLin );
	else if (mInt == "nlin1") // interpolacja nieliniowa prosta
		return ( tEvLin /*- mAl*mGa*mAs*0.*/ /*- mAl*mGa*mSb*0.*/ - mAl*mAs*mSb*(-1.71) - mGa*mAs*mSb*(-1.06) );
	else if (mInt == "nlin2") // interpolacja nieliniowa zlozona
	{
		double tEvAlGaAs = mAl * mAlAs.Ev() + mGa * mGaAs.Ev() /*- mAl * mGa * 0.*/;
		double tEvAlGaSb = mAl * mAlSb.Ev() + mGa * mGaSb.Ev() /*- mAl * mGa * 0.*/;
		double tEvAlAsSb = mAs * mAlAs.Ev() + mSb * mAlSb.Ev() - mAs * mSb * (-1.71);
		double tEvGaAsSb = mAs * mGaAs.Ev() + mSb * mGaSb.Ev() - mAs * mSb * (-1.06);
		return ( (mAl*mGa*(mAs*tEvAlGaAs+mSb*tEvAlGaSb) + (mAs*mSb*(mAl*tEvAlAsSb+mGa*tEvGaAsSb))) / (mAl*mGa+mAs*mSb) );
	}
	else return 0.;
}
//------------------------------------------------------------------------------
double AlGaAsSb::Ec(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, AlSb, GaAs i GaSb";
	}
	return ( Ev() + Eg(iT) );
}
//------------------------------------------------------------------------------
double AlGaAsSb::ac(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, AlSb, GaAs i GaSb";
	}
	double tacLin = mAl*mAs*mAlAs.ac() + mAl*mSb*mAlSb.ac() + mGa*mAs*mGaAs.ac() + mGa*mSb*mGaSb.ac();
	return ( tacLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double AlGaAsSb::av(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, AlSb, GaAs i GaSb";
	}
	double tavLin = mAl*mAs*mAlAs.av() + mAl*mSb*mAlSb.av() + mGa*mAs*mGaAs.av() + mGa*mSb*mGaSb.av();
	return ( tavLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double AlGaAsSb::b(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, AlSb, GaAs i GaSb";
	}
	double tbLin = mAl*mAs*mAlAs.b() + mAl*mSb*mAlSb.b() + mGa*mAs*mGaAs.b() + mGa*mSb*mGaSb.b();
	return ( tbLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double AlGaAsSb::d(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, AlSb, GaAs i GaSb";
	}
	double tdLin = mAl*mAs*mAlAs.d() + mAl*mSb*mAlSb.d() + mGa*mAs*mGaAs.d() + mGa*mSb*mGaSb.d();
	return ( tdLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double AlGaAsSb::c11(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, AlSb, GaAs i GaSb";
	}
	double tc11Lin = mAl*mAs*mAlAs.c11() + mAl*mSb*mAlSb.c11() + mGa*mAs*mGaAs.c11() + mGa*mSb*mGaSb.c11();
	return ( tc11Lin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double AlGaAsSb::c12(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, AlSb, GaAs i GaSb";
	}
	double tc12Lin = mAl*mAs*mAlAs.c12() + mAl*mSb*mAlSb.c12() + mGa*mAs*mGaAs.c12() + mGa*mSb*mGaSb.c12();
	return ( tc12Lin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double AlGaAsSb::c44(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, AlSb, GaAs i GaSb";
	}
	double tc44Lin = mAl*mAs*mAlAs.c44() + mAl*mSb*mAlSb.c44() + mGa*mAs*mGaAs.c44() + mGa*mSb*mGaSb.c44();
	return ( tc44Lin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double AlGaAsSb::Nc(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "standardowy wzor";
	}
	return ( cFunc::Nc(iT, me()) );
}
//------------------------------------------------------------------------------
double AlGaAsSb::Nv(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "standardowy wzor";
	}
	return ( cFunc::Nv(iT, mh()) );
}
//------------------------------------------------------------------------------
double AlGaAsSb::ni(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "standardowy wzor";
	}
	return ( cFunc::ni(iT, me(), mh(), Eg(iT)) );
}
//------------------------------------------------------------------------------
double AlGaAsSb::k(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, AlSb, GaAs i GaSb";
	}
	return ( 1./(mAl*mAs/mAlAs.k(iT) + mAl*mSb/mAlSb.k(iT) + mGa*mAs/mGaAs.k(iT) + mGa*mSb/mGaSb.k(iT) + mAl*mGa*0.32 + mAs*mSb*0.91) );
}
//------------------------------------------------------------------------------
double AlGaAsSb::cp(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, AlSb, GaAs i GaSb";
	}
	double tcpLin = mAl*mAs*mAlAs.cp(iT) + mAl*mSb*mAlSb.cp(iT) + mGa*mAs*mGaAs.cp(iT) + mGa*mSb*mGaSb.cp(iT);
	return ( tcpLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double AlGaAsSb::g(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, AlSb, GaAs i GaSb";
	}
	double tgLin = mAl*mAs*mAlAs.g(iT) + mAl*mSb*mAlSb.g(iT) + mGa*mAs*mGaAs.g(iT) + mGa*mSb*mGaSb.g(iT);
	return ( tgLin ); // lin = nlin1 = nlin2
}
//---------------------------------------------------------------------------
void AlGaAsSb::setInt(std::string iInt)
{
	mInt = iInt;
}
//---------------------------------------------------------------------------
AlGaAsSb::AlGaAsSb(double iAl,double iAs)
{
	mAl = iAl;
	mGa = 1.-iAl;
	mAs = iAs;
	mSb = 1.-mAs;
	mInt = "nlin1";
}
//---------------------------------------------------------------------------
AlGaAsSb::AlGaAsSb()
{
}
//---------------------------------------------------------------------------
AlGaAsSb::~AlGaAsSb()
{
}
