#include "AlGaInAs.h"
//------------------------------------------------------------------------------
double AlGaInAs::a(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, GaAs i InAs";
	}
	return ( mAl * mAlAs.a(iT) + mGa * mGaAs.a(iT) + mIn * mInAs.a(iT) );
}
//------------------------------------------------------------------------------
double AlGaInAs::Eg(double iT, char iPoint, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, GaAs i InAs";
	}
	double tEgLin = mAl * mAlAs.Eg(iT, iPoint) + mGa * mGaAs.Eg(iT, iPoint) + mIn * mInAs.Eg(iT, iPoint);
	if (mInt == "lin") // interpolacja liniowa
		return ( tEgLin );
	else if (mInt == "nlin1") // interpolacja nieliniowa prosta
	{
		if (iPoint == 'G') return ( tEgLin - mAl*mGa*(-0.127+1.310*mAl) - mAl*mIn*0.70 - mGa*mIn*0.477 - mAl*mGa*mIn*0.22 );
		else if (iPoint == 'X') return ( tEgLin - mAl*mGa*0.055 /*- mAl*mIn*0.*/ - mGa*mIn*1.4 );
		else if (iPoint == 'L') return ( tEgLin /*- mAl*mGa*0.*/ /*- mAl*mIn*0.*/ - mGa*mIn*0.33 );
		else return 0.;
	}
	else if (mInt == "nlin2") // interpolacja nieliniowa zlozona
	{
		double tU = 0.5*(1.-mIn+mAl);
		double tV = 0.5*(1.-mAl+mGa);
		double tZ = 0.5*(1.-mGa+mIn);
		if (iPoint == 'G')
		{
			double tEgAlInAs = tU * mAlAs.Eg(iT,iPoint) + (1.-tU) * mInAs.Eg(iT,iPoint) - tU * (1.-tU) * 0.70;
			double tEgAlGaAs = tV * mGaAs.Eg(iT,iPoint) + (1.-tV) * mAlAs.Eg(iT,iPoint) - tV * (1.-tV) * (-0.127+1.310*(1.-tV));
			double tEgInGaAs = tZ * mInAs.Eg(iT,iPoint) + (1.-tZ) * mGaAs.Eg(iT,iPoint) - tZ * (1.-tZ) * 0.477;
			return ( (mIn*mAl*tEgAlInAs + mAl*mGa*tEgAlGaAs + mGa*mIn*tEgInGaAs - mAl*mGa*mIn*0.22)/(mIn*mAl + mAl*mGa + mGa*mIn) );
		}
		else if (iPoint == 'X')
		{
			double tEgAlInAs = tU * mAlAs.Eg(iT,iPoint) + (1.-tU) * mInAs.Eg(iT,iPoint) /*- tU * (1.-tU) * 0.*/;
			double tEgAlGaAs = tV * mGaAs.Eg(iT,iPoint) + (1.-tV) * mAlAs.Eg(iT,iPoint) - tV * (1.-tV) * 0.055;
			double tEgInGaAs = tZ * mInAs.Eg(iT,iPoint) + (1.-tZ) * mGaAs.Eg(iT,iPoint) - tZ * (1.-tZ) * 1.4;
			return ( (mIn*mAl*tEgAlInAs + mAl*mGa*tEgAlGaAs + mGa*mIn*tEgInGaAs)/(mIn*mAl + mAl*mGa + mGa*mIn) );
		}
		else if (iPoint == 'L')
		{
			double tEgAlInAs = tU * mAlAs.Eg(iT,iPoint) + (1.-tU) * mInAs.Eg(iT,iPoint) /*- tU * (1.-tU) * 0.*/;
			double tEgAlGaAs = tV * mGaAs.Eg(iT,iPoint) + (1.-tV) * mAlAs.Eg(iT,iPoint) /*- tV * (1.-tV) * 0.*/;
			double tEgInGaAs = tZ * mInAs.Eg(iT,iPoint) + (1.-tZ) * mGaAs.Eg(iT,iPoint) - tZ * (1.-tZ) * 0.33;
			return ( (mIn*mAl*tEgAlInAs + mAl*mGa*tEgAlGaAs + mGa*mIn*tEgInGaAs)/(mIn*mAl + mAl*mGa + mGa*mIn) );
		}
		else return 0.;
	}
	else return 0.;
}
//------------------------------------------------------------------------------
double AlGaInAs::Eg(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, GaAs i InAs";
	}
	double tEgG = Eg(iT, 'G');
	double tEgX = Eg(iT, 'X');
	double tEgL = Eg(iT, 'L');
	if ((tEgG <= tEgX) && (tEgG <= tEgL)) return tEgG;
	else if (tEgX <= tEgL) return tEgX;
	else return tEgL;
}
//------------------------------------------------------------------------------
double AlGaInAs::Dso(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, GaAs i InAs";
	}
	double tDsoLin = mAl * mAlAs.Dso() + mGa * mGaAs.Dso() + mIn * mInAs.Dso();
	if (mInt == "lin") // interpolacja liniowa
		return ( tDsoLin );
	else if (mInt == "nlin1") // interpolacja nieliniowa prosta
		return ( tDsoLin /*- mAl*mGa*0.*/ - mAl*mIn*0.15 - mGa*mIn*0.15 );
	else if (mInt == "nlin2") // interpolacja nieliniowa zlozona
	{
		double tU = 0.5*(1.-mIn+mAl);
		double tV = 0.5*(1.-mAl+mGa);
		double tZ = 0.5*(1.-mGa+mIn);
		double tDsoAlInAs = tU * mAlAs.Dso() + (1.-tU) * mInAs.Dso() - tU * (1.-tU) * 0.15;
		double tDsoAlGaAs = tV * mGaAs.Dso() + (1.-tV) * mAlAs.Dso() /*- tV * (1.-tV) * 0.*/;
		double tDsoInGaAs = tZ * mInAs.Dso() + (1.-tZ) * mGaAs.Dso() - tZ * (1.-tZ) * 0.15;
		return ( (mIn*mAl*tDsoAlInAs + mAl*mGa*tDsoAlGaAs + mGa*mIn*tDsoInGaAs)/(mIn*mAl + mAl*mGa + mGa*mIn) );
	}
	else return 0.;
}
//------------------------------------------------------------------------------
double AlGaInAs::me(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, GaAs i InAs";
	}
	double tmeLin = mAl * mAlAs.me() + mGa * mGaAs.me() + mIn * mInAs.me();
	if (mInt == "lin") // interpolacja liniowa
		return ( tmeLin );
	else if (mInt == "nlin1") // interpolacja nieliniowa prosta
		return ( tmeLin /*- mAl*mGa*0.*/ - mAl*mIn*0.012 - mGa*mIn*0.008 );
	else if (mInt == "nlin2") // interpolacja nieliniowa zlozona
	{
		double tU = 0.5*(1.-mIn+mAl);
		double tV = 0.5*(1.-mAl+mGa);
		double tZ = 0.5*(1.-mGa+mIn);
		double tmeAlInAs = tU * mAlAs.me() + (1.-tU) * mInAs.me() - tU * (1.-tU) * 0.012;
		double tmeAlGaAs = tV * mGaAs.me() + (1.-tV) * mAlAs.me() /*- tV * (1.-tV) * 0.*/;
		double tmeInGaAs = tZ * mInAs.me() + (1.-tZ) * mGaAs.me() - tZ * (1.-tZ) * 0.008;
		return ( (mIn*mAl*tmeAlInAs + mAl*mGa*tmeAlGaAs + mGa*mIn*tmeInGaAs)/(mIn*mAl + mAl*mGa + mGa*mIn) );
	}
	else return 0.;
}
//------------------------------------------------------------------------------
double AlGaInAs::mhh(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, GaAs i InAs";
	}
	double tmhhLin = mAl * mAlAs.mhh() + mGa * mGaAs.mhh() + mIn * mInAs.mhh();
	return ( tmhhLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double AlGaInAs::mlh(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, GaAs i InAs";
	}
	double tmlhLin = mAl * mAlAs.mlh() + mGa * mGaAs.mlh() + mIn * mInAs.mlh();
	return ( tmlhLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double AlGaInAs::mso(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, GaAs i InAs";
	}
	double tmsoLin = mAl * mAlAs.mso() + mGa * mGaAs.mso() + mIn * mInAs.mso();
	return ( tmsoLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double AlGaInAs::mh(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "mh = (mlh^3/2+mhh^3/2)^2/3";
	}
	return ( pow(pow(mlh(), 1.5) + pow(mhh(), 1.5), 2./3.) );
}
//------------------------------------------------------------------------------
double AlGaInAs::Ev(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, GaAs i InAs";
	}
	double tEvLin = mAl * mAlAs.Ev() + mGa * mGaAs.Ev() + mIn * mInAs.Ev();
	if (mInt == "lin") // interpolacja liniowa
		return ( tEvLin );
	else if (mInt == "nlin1") // interpolacja nieliniowa prosta
		return ( tEvLin /*- mAl*mGa*0.*/ - mAl*mIn*(-0.64) - mGa*mIn*(-0.38) );
	else if (mInt == "nlin2") // interpolacja nieliniowa zlozona
	{
		double tU = 0.5*(1.-mIn+mAl);
		double tV = 0.5*(1.-mAl+mGa);
		double tZ = 0.5*(1.-mGa+mIn);
		double tEvAlInAs = tU * mAlAs.Ev() + (1.-tU) * mInAs.Ev() - tU * (1.-tU) * (-0.64);
		double tEvAlGaAs = tV * mGaAs.Ev() + (1.-tV) * mAlAs.Ev() /*- tV * (1.-tV) * 0.*/;
		double tEvInGaAs = tZ * mInAs.Ev() + (1.-tZ) * mGaAs.Ev() - tZ * (1.-tZ) * (-0.38);
		return ( (mIn*mAl*tEvAlInAs + mAl*mGa*tEvAlGaAs + mGa*mIn*tEvInGaAs)/(mIn*mAl + mAl*mGa + mGa*mIn) );
	}
	else return 0.;
}
//------------------------------------------------------------------------------
double AlGaInAs::Ec(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, GaAs i InAs";
	}
	return ( Ev() + Eg(iT) );
}
//------------------------------------------------------------------------------
double AlGaInAs::ac(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, GaAs i InAs";
	}
	double tacLin = mAl * mAlAs.ac() + mGa * mGaAs.ac() + mIn * mInAs.ac();
	if (mInt == "lin") // interpolacja liniowa
		return ( tacLin );
	else if (mInt == "nlin1") // interpolacja nieliniowa prosta
		return ( tacLin /*- mAl*mGa*0.*/ - mAl*mIn*(-1.4) - mGa*mIn*2.61 );
	else if (mInt == "nlin2") // interpolacja nieliniowa zlozona
	{
		double tU = 0.5*(1.-mIn+mAl);
		double tV = 0.5*(1.-mAl+mGa);
		double tZ = 0.5*(1.-mGa+mIn);
		double tEvAlInAs = tU * mAlAs.Ev() + (1.-tU) * mInAs.Ev() - tU * (1.-tU) * (-1.4);
		double tEvAlGaAs = tV * mGaAs.Ev() + (1.-tV) * mAlAs.Ev() /*- tV * (1.-tV) * 0.*/;
		double tEvInGaAs = tZ * mInAs.Ev() + (1.-tZ) * mGaAs.Ev() - tZ * (1.-tZ) * 2.61;
		return ( (mIn*mAl*tEvAlInAs + mAl*mGa*tEvAlGaAs + mGa*mIn*tEvInGaAs)/(mIn*mAl + mAl*mGa + mGa*mIn) );
	}
	else return 0.;
}
//------------------------------------------------------------------------------
double AlGaInAs::av(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, GaAs i InAs";
	}
	double tavLin = mAl * mAlAs.av() + mGa * mGaAs.av() + mIn * mInAs.av();
	return ( tavLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double AlGaInAs::b(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, GaAs i InAs";
	}
	double tbLin = mAl * mAlAs.b() + mGa * mGaAs.b() + mIn * mInAs.b();
	return ( tbLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double AlGaInAs::d(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, GaAs i InAs";
	}
	double tdLin = mAl * mAlAs.d() + mGa * mGaAs.d() + mIn * mInAs.d();
	return ( tdLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double AlGaInAs::c11(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, GaAs i InAs";
	}
	double tc11Lin = mAl * mAlAs.c11() + mGa * mGaAs.c11() + mIn * mInAs.c11();
	return ( tc11Lin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double AlGaInAs::c12(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, GaAs i InAs";
	}
	double tc12Lin = mAl * mAlAs.c12() + mGa * mGaAs.c12() + mIn * mInAs.c12();
	return ( tc12Lin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double AlGaInAs::c44(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, GaAs i InAs";
	}
	double tc44Lin = mAl * mAlAs.c44() + mGa * mGaAs.c44() + mIn * mInAs.c44();
	return ( tc44Lin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double AlGaInAs::Nc(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "standardowy wzor";
	}
	return ( cFunc::Nc(iT, me()) );
}
//------------------------------------------------------------------------------
double AlGaInAs::Nv(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "standardowy wzor";
	}
	return ( cFunc::Nv(iT, mh()) );
}
//------------------------------------------------------------------------------
double AlGaInAs::ni(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "standardowy wzor";
	}
	return ( cFunc::ni(iT, me(), mh(), Eg(iT)) );
}
//------------------------------------------------------------------------------
double AlGaInAs::k(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, GaAs i InAs";
	}
	return ( 1./(mAl/mAlAs.k(iT) + mGa/mGaAs.k(iT) + mIn/mInAs.k(iT) + mAl*mGa*0.32 + mAl*mIn*0.15 + mGa*mIn*0.72) );
}
//------------------------------------------------------------------------------
double AlGaInAs::cp(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, GaAs i InAs";
	}
	double tcpLin = mAl * mAlAs.cp(iT) + mGa * mGaAs.cp(iT) + mIn * mInAs.cp(iT);
	return ( tcpLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double AlGaInAs::g(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla AlAs, GaAs i InAs";
	}
	double tgLin = mAl * mAlAs.g(iT) + mGa * mGaAs.g(iT) + mIn * mInAs.g(iT);
	return ( tgLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double AlGaInAs::nR(double iLam, double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "H. Dejun and K.T. Chan";
		ipRef->title = "Refractive index of AlInGaAs layers in the transparent wavelength regio";
		ipRef->journal = "-";
		ipRef->comment = "zaleznosc poprawna dla 1130-1550 nm gdy: Al=0.25-0.33 oraz In ok.53";
	}
	if ( (iLam>=1130.0) && (iLam<=1550.0) )
	{
		double E0 = 1.424+1.455*mAl + 0.191*mAl*mAl - 1.614*mIn + 0.55*mIn*mIn + 0.043*mAl*mIn;
		double Dso = 0.3*mAl + 0.43*mIn + 0.34*mGa;
		double X = cFunc::LamtoE(iLam) / E0;
		double Xso = cFunc::LamtoE(iLam) / (E0+Dso);
		double fX = (2.-sqrt(1.+X)-sqrt(1.-X))/X/X;
		double fXso = (2.-sqrt(1.+Xso)-sqrt(1.-Xso))/Xso/Xso;
		double A0 = 2.9715 + 11.6407*mAl + 1.5749*mIn;
		double B0 = 8.7279 - 10.2892*mAl + 4.62578*mIn;
		double eps1 = A0*(fX+0.5*pow(E0/(E0+Dso),1.5)*fXso)+B0;
		return ( sqrt(eps1) );
	}
	else
		return 0.;
}
//---------------------------------------------------------------------------
void AlGaInAs::setInt(std::string iInt)
{
	mInt = iInt;
}
//---------------------------------------------------------------------------
AlGaInAs::AlGaInAs(double iAl,double iGa)
{
	mAl = iAl;
	mGa = iGa;
	mIn = 1.-iAl-iGa;
	mInt = "nlin1";
}
//---------------------------------------------------------------------------
AlGaInAs::AlGaInAs()
{
}
//---------------------------------------------------------------------------
AlGaInAs::~AlGaInAs()
{
}
