#include "AlNzb.h"
//------------------------------------------------------------------------------
double AlNzb::a(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman and J. R. Meyer";
		ipRef->title = "Band parameters for nitrogen-containing semiconductors";
		ipRef->journal = "Journal of Applied Physics, vol. 94, no. 6, pp. 3675-3696, 2003";
		ipRef->comment = " ";
	}
	return ( 4.38+1.47e-5*(iT-300.) );
}
//------------------------------------------------------------------------------
double AlNzb::Eg(double iT, char iPoint, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman and J. R. Meyer";
		ipRef->title = "Band parameters for nitrogen-containing semiconductors";
		ipRef->journal = "Journal of Applied Physics, vol. 94, no. 6, pp. 3675-3696, 2003";
		ipRef->comment = " ";
	}
	if (iPoint == 'G') return ( cFunc::Varshni(5.4, 0.593e-3, 600., iT) );
	else if (iPoint == 'X') return ( cFunc::Varshni(4.9, 0.593e-3, 600., iT) );
	else if (iPoint == 'L') return ( cFunc::Varshni(9.3, 0.593e-3, 600., iT) );
	else return 0.;
}
//------------------------------------------------------------------------------
double AlNzb::Eg(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman and J. R. Meyer";
		ipRef->title = "Band parameters for nitrogen-containing semiconductors";
		ipRef->journal = "Journal of Applied Physics, vol. 94, no. 6, pp. 3675-3696, 2003";
		ipRef->comment = " ";
	}
	double tEgG = Eg(iT, 'G');
	double tEgX = Eg(iT, 'X');
	double tEgL = Eg(iT, 'L');
	if ((tEgG <= tEgX) && (tEgG <= tEgL)) return tEgG;
	else if (tEgX <= tEgL) return tEgX;
	else return tEgL;
}
//------------------------------------------------------------------------------
double AlNzb::Dso(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman and J. R. Meyer";
		ipRef->title = "Band parameters for nitrogen-containing semiconductors";
		ipRef->journal = "Journal of Applied Physics, vol. 94, no. 6, pp. 3675-3696, 2003";
		ipRef->comment = " ";
	}
	return ( 0.019 );
}
//------------------------------------------------------------------------------
double AlNzb::me(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = " ";
	}
	return ( 0.26 );
}
//------------------------------------------------------------------------------
double AlNzb::mhh(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = " ";
	}
	return ( 1.15 );
}
//------------------------------------------------------------------------------
double AlNzb::mlh(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = " ";
	}
	return ( 0.39 );
}
//------------------------------------------------------------------------------
double AlNzb::mso(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman and J. R. Meyer";
		ipRef->title = "Band parameters for nitrogen-containing semiconductors";
		ipRef->journal = "Journal of Applied Physics, vol. 94, no. 6, pp. 3675-3696, 2003";
		ipRef->comment = " ";
	}
	return ( 0.47 );
}
//------------------------------------------------------------------------------
double AlNzb::mh(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "mh = (mlh^3/2+mhh^3/2)^2/3";
	}
	return ( pow(pow(mlh(), 1.5) + pow(mhh(), 1.5), 2./3.) );
}
//------------------------------------------------------------------------------
double AlNzb::Ev(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman and J. R. Meyer";
		ipRef->title = "Band parameters for nitrogen-containing semiconductors";
		ipRef->journal = "Journal of Applied Physics, vol. 94, no. 6, pp. 3675-3696, 2003";
		ipRef->comment = " ";
	}
	return ( -3.44 );
}
//------------------------------------------------------------------------------
double AlNzb::Ec(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman and J. R. Meyer";
		ipRef->title = "Band parameters for nitrogen-containing semiconductors";
		ipRef->journal = "Journal of Applied Physics, vol. 94, no. 6, pp. 3675-3696, 2003";
		ipRef->comment = " ";
	}
	return ( Ev() + Eg(iT) );
}
//------------------------------------------------------------------------------
double AlNzb::ac(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman and J. R. Meyer";
		ipRef->title = "Band parameters for nitrogen-containing semiconductors";
		ipRef->journal = "Journal of Applied Physics, vol. 94, no. 6, pp. 3675-3696, 2003";
		ipRef->comment = " ";
	}
	return ( -4.5 );
}
//------------------------------------------------------------------------------
double AlNzb::av(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman and J. R. Meyer";
		ipRef->title = "Band parameters for nitrogen-containing semiconductors";
		ipRef->journal = "Journal of Applied Physics, vol. 94, no. 6, pp. 3675-3696, 2003";
		ipRef->comment = " ";
	}
	return ( -4.9 );
}
//------------------------------------------------------------------------------
double AlNzb::b(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman and J. R. Meyer";
		ipRef->title = "Band parameters for nitrogen-containing semiconductors";
		ipRef->journal = "Journal of Applied Physics, vol. 94, no. 6, pp. 3675-3696, 2003";
		ipRef->comment = " ";
	}
	return ( -1.7 );
}
//------------------------------------------------------------------------------
double AlNzb::d(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman and J. R. Meyer";
		ipRef->title = "Band parameters for nitrogen-containing semiconductors";
		ipRef->journal = "Journal of Applied Physics, vol. 94, no. 6, pp. 3675-3696, 2003";
		ipRef->comment = " ";
	}
	return ( -5.5 );
}
//------------------------------------------------------------------------------
double AlNzb::c11(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman and J. R. Meyer";
		ipRef->title = "Band parameters for nitrogen-containing semiconductors";
		ipRef->journal = "Journal of Applied Physics, vol. 94, no. 6, pp. 3675-3696, 2003";
		ipRef->comment = " ";
	}
	return ( 304. );
}
//------------------------------------------------------------------------------
double AlNzb::c12(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman and J. R. Meyer";
		ipRef->title = "Band parameters for nitrogen-containing semiconductors";
		ipRef->journal = "Journal of Applied Physics, vol. 94, no. 6, pp. 3675-3696, 2003";
		ipRef->comment = " ";
	}
	return ( 160. );
}
//------------------------------------------------------------------------------
double AlNzb::c44(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman and J. R. Meyer";
		ipRef->title = "Band parameters for nitrogen-containing semiconductors";
		ipRef->journal = "Journal of Applied Physics, vol. 94, no. 6, pp. 3675-3696, 2003";
		ipRef->comment = " ";
	}
	return ( 193. );
}
//------------------------------------------------------------------------------
double AlNzb::Nc(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "standardowy wzor";
	}
	return ( cFunc::Nc(iT, me()) );
}
//------------------------------------------------------------------------------
double AlNzb::Nv(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "standardowy wzor";
	}
	return ( cFunc::Nv(iT, mh()) );
}
//------------------------------------------------------------------------------
double AlNzb::ni(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "standardowy wzor";
	}
	return ( cFunc::ni(iT, me(), mh(), Eg(iT)) );
}
//---------------------------------------------------------------------------
double AlNzb::g(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = " ";
	}
	return ( 3.24e3 );
}
//------------------------------------------------------------------------------
AlNzb::AlNzb()
{
}
//------------------------------------------------------------------------------
AlNzb::~AlNzb()
{
}
//------------------------------------------------------------------------------
