#include "GaInAsP.h"
//------------------------------------------------------------------------------
double GaInAsP::a(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaP, InAs i InP";
	}
	return ( mGa*mAs*mGaAs.a(iT) + mGa*mP*mGaP.a(iT) + mIn*mAs*mInAs.a(iT) + mIn*mP*mInP.a(iT) );
}
//------------------------------------------------------------------------------
double GaInAsP::Eg(double iT, char iPoint, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaP, InAs i InP";
	}
	double tEgLin = mGa*mAs*mGaAs.Eg(iT, iPoint) + mGa*mP*mGaP.Eg(iT, iPoint) + mIn*mAs*mInAs.Eg(iT, iPoint) + mIn*mP*mInP.Eg(iT, iPoint);
	if (mInt == "lin") // interpolacja liniowa
		return ( tEgLin );
	else if (mInt == "nlin1") // interpolacja nieliniowa prosta
	{
		if (iPoint == 'G') return ( tEgLin - mGa*mIn*mAs*0.477 - mGa*mIn*mP*0.65 - mGa*mAs*mP*0.19 - mIn*mAs*mP*0.10 - mGa*mIn*mAs*mP*0.13 );
		else if (iPoint == 'X') return ( tEgLin - mGa*mIn*mAs*1.4 - mGa*mIn*mP*0.20 - mGa*mAs*mP*0.24 - mIn*mAs*mP*0.27 );
		else if (iPoint == 'L') return ( tEgLin - mGa*mIn*mAs*0.33 - mGa*mIn*mP*1.03 - mGa*mAs*mP*0.16 - mIn*mAs*mP*0.27 );
		else return 0.;
	}
	else if (mInt == "nlin2") // interpolacja nieliniowa zlozona
	{
		if (iPoint == 'G')
		{
			double tEgGaInAs = mGa * mGaAs.Eg(iT,iPoint) + mIn * mInAs.Eg(iT,iPoint) - mGa * mIn * 0.477;
			double tEgGaInP = mGa * mGaP.Eg(iT,iPoint) + mIn * mInP.Eg(iT,iPoint) - mGa * mIn * 0.65;
			double tEgGaAsP = mAs * mGaAs.Eg(iT,iPoint) + mP * mGaP.Eg(iT,iPoint) - mAs * mP * 0.19;
			double tEgInAsP = mAs * mInAs.Eg(iT,iPoint) + mP * mInP.Eg(iT,iPoint) - mAs * mP * 0.10;
			return ( (mGa*mIn*(mAs*tEgGaInAs+mP*tEgGaInP-mAs*mP*0.13) + (mAs*mP*(mGa*tEgGaAsP+mIn*tEgInAsP-mGa*mIn*0.13))) / (mGa*mIn+mAs*mP) );
		}
		else if (iPoint == 'X')
		{
			double tEgGaInAs = mGa * mGaAs.Eg(iT,iPoint) + mIn * mInAs.Eg(iT,iPoint) - mGa * mIn * 1.4;
			double tEgGaInP = mGa * mGaP.Eg(iT,iPoint) + mIn * mInP.Eg(iT,iPoint) - mGa * mIn * 0.20;
			double tEgGaAsP = mAs * mGaAs.Eg(iT,iPoint) + mP * mGaP.Eg(iT,iPoint) - mAs * mP * 0.24;
			double tEgInAsP = mAs * mInAs.Eg(iT,iPoint) + mP * mInP.Eg(iT,iPoint) - mAs * mP * 0.27;
			return ( (mGa*mIn*(mAs*tEgGaInAs+mP*tEgGaInP) + (mAs*mP*(mGa*tEgGaAsP+mIn*tEgInAsP))) / (mGa*mIn+mAs*mP) );
		}
		else if (iPoint == 'L')
		{
			double tEgGaInAs = mGa * mGaAs.Eg(iT,iPoint) + mIn * mInAs.Eg(iT,iPoint) - mGa * mIn * 0.33;
			double tEgGaInP = mGa * mGaP.Eg(iT,iPoint) + mIn * mInP.Eg(iT,iPoint) - mGa * mIn * 1.03;
			double tEgGaAsP = mAs * mGaAs.Eg(iT,iPoint) + mP * mGaP.Eg(iT,iPoint) - mAs * mP * 0.16;
			double tEgInAsP = mAs * mInAs.Eg(iT,iPoint) + mP * mInP.Eg(iT,iPoint) - mAs * mP * 0.27;
			return ( (mGa*mIn*(mAs*tEgGaInAs+mP*tEgGaInP) + (mAs*mP*(mGa*tEgGaAsP+mIn*tEgInAsP))) / (mGa*mIn+mAs*mP) );
		}
		else return 0.;
	}
	else return 0.;
}
//------------------------------------------------------------------------------
double GaInAsP::Eg(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaP, InAs i InP";
	}
	double tEgG = Eg(iT, 'G');
	double tEgX = Eg(iT, 'X');
	double tEgL = Eg(iT, 'L');
	if ((tEgG <= tEgX) && (tEgG <= tEgL)) return tEgG;
	else if (tEgX <= tEgL) return tEgX;
	else return tEgL;
}
//------------------------------------------------------------------------------
double GaInAsP::Dso(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaP, InAs i InP";
	}
	double tDsoLin = mGa*mAs*mGaAs.Dso() + mGa*mP*mGaP.Dso() + mIn*mAs*mInAs.Dso() + mIn*mP*mInP.Dso();
	if (mInt == "lin") // interpolacja liniowa
		return ( tDsoLin );
	else if (mInt == "nlin1") // interpolacja nieliniowa prosta
		return ( tDsoLin - mGa*mIn*mAs*0.15 /*- mGa*mIn*mP*0.*/ /*- mGa*mAs*mP*0.*/ - mIn*mAs*mP*0.16 );
	else if (mInt == "nlin2") // interpolacja nieliniowa zlozona
	{
		double tDsoGaInAs = mGa * mGaAs.Dso() + mIn * mInAs.Dso() - mGa * mIn * 0.15;
		double tDsoGaInP = mGa * mGaP.Dso() + mIn * mInP.Dso() /*- mGa * mIn * 0.*/;
		double tDsoGaAsP = mAs * mGaAs.Dso() + mP * mGaP.Dso() /*- mAs * mP * 0.*/;
		double tDsoInAsP = mAs * mInAs.Dso() + mP * mInP.Dso() - mAs * mP * 0.16;
		return ( (mGa*mIn*(mAs*tDsoGaInAs+mP*tDsoGaInP) + (mAs*mP*(mGa*tDsoGaAsP+mIn*tDsoInAsP))) / (mGa*mIn+mAs*mP) );
	}
	else return 0.;
}
//------------------------------------------------------------------------------
double GaInAsP::me(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaP, InAs i InP";
	}
	double tmeLin = mGa*mAs*mGaAs.me() + mGa*mP*mGaP.me() + mIn*mAs*mInAs.me() + mIn*mP*mInP.me();
	if (mInt == "lin") // interpolacja liniowa
		return ( tmeLin );
	else if (mInt == "nlin1") // interpolacja nieliniowa prosta
		return ( tmeLin - mGa*mIn*mAs*0.008 - mGa*mIn*mP*0.01854 /*- mGa*mAs*mP*0.*/ /*- mIn*mAs*mP*0.*/ );
	else if (mInt == "nlin2") // interpolacja nieliniowa zlozona
	{
		double tmeGaInAs = mGa * mGaAs.me() + mIn * mInAs.me() - mGa * mIn * 0.008;
		double tmeGaInP = mGa * mGaP.me() + mIn * mInP.me() - mGa * mIn * 0.01854;
		double tmeGaAsP = mAs * mGaAs.me() + mP * mGaP.me() /*- mAs * mP * 0.*/;
		double tmeInAsP = mAs * mInAs.me() + mP * mInP.me() /*- mAs * mP * 0.*/;
		return ( (mGa*mIn*(mAs*tmeGaInAs+mP*tmeGaInP) + (mAs*mP*(mGa*tmeGaAsP+mIn*tmeInAsP))) / (mGa*mIn+mAs*mP) );
	}
	else return 0.;
}
//------------------------------------------------------------------------------
double GaInAsP::mhh(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaP, InAs i InP";
	}
	double tmhhLin = mGa*mAs*mGaAs.mhh() + mGa*mP*mGaP.mhh() + mIn*mAs*mInAs.mhh() + mIn*mP*mInP.mhh();
	return ( tmhhLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double GaInAsP::mlh(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaP, InAs i InP";
	}
	double tmlhLin = mGa*mAs*mGaAs.mlh() + mGa*mP*mGaP.mlh() + mIn*mAs*mInAs.mlh() + mIn*mP*mInP.mlh();
	return ( tmlhLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double GaInAsP::mso(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaP, InAs i InP";
	}
	double tmsoLin = mGa*mAs*mGaAs.mso() + mGa*mP*mGaP.mso() + mIn*mAs*mInAs.mso() + mIn*mP*mInP.mso();
	return ( tmsoLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double GaInAsP::mh(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "mh = (mlh^3/2+mhh^3/2)^2/3";
	}
	return ( pow(pow(mlh(), 1.5) + pow(mhh(), 1.5), 2./3.) );
}
//------------------------------------------------------------------------------
double GaInAsP::Ev(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaP, InAs i InP";
	}
	double tEvLin = mGa*mAs*mGaAs.Ev() + mGa*mP*mGaP.Ev() + mIn*mAs*mInAs.Ev() + mIn*mP*mInP.Ev();
	if (mInt == "lin") // interpolacja liniowa
		return ( tEvLin );
	else if (mInt == "nlin1") // interpolacja nieliniowa prosta
		return ( tEvLin - mGa*mIn*mAs*(-0.38) /*- mGa*mIn*mP*0.*/ /*- mGa*mAs*mP*0.*/ /*- mIn*mAs*mP*0.*/ );
	else if (mInt == "nlin2") // interpolacja nieliniowa zlozona
	{
		double tEvGaInAs = mGa * mGaAs.Ev() + mIn * mInAs.Ev() - mGa * mIn * (-0.38);
		double tEvGaInP = mGa * mGaP.Ev() + mIn * mInP.Ev() /*- mGa * mIn * 0.*/;
		double tEvGaAsP = mAs * mGaAs.Ev() + mP * mGaP.Ev() /*- mAs * mP * 0.*/;
		double tEvInAsP = mAs * mInAs.Ev() + mP * mInP.Ev() /*- mAs * mP * 0.*/;
		return ( (mGa*mIn*(mAs*tEvGaInAs+mP*tEvGaInP) + (mAs*mP*(mGa*tEvGaAsP+mIn*tEvInAsP))) / (mGa*mIn+mAs*mP) );
	}
	else return 0.;
}
//------------------------------------------------------------------------------
double GaInAsP::Ec(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaP, InAs i InP";
	}
	return ( Ev() + Eg(iT) );
}
//------------------------------------------------------------------------------
double GaInAsP::ac(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaP, InAs i InP";
	}
	double tacLin = mGa*mAs*mGaAs.ac() + mGa*mP*mGaP.ac() + mIn*mAs*mInAs.ac() + mIn*mP*mInP.ac();
	if (mInt == "lin") // interpolacja liniowa
		return ( tacLin );
	else if (mInt == "nlin1") // interpolacja nieliniowa prosta
		return ( tacLin - mGa*mIn*mAs*2.61 /*- mGa*mIn*mP*0.*/ /*- mGa*mAs*mP*0.*/ /*- mIn*mAs*mP*0.*/ );
	else if (mInt == "nlin2") // interpolacja nieliniowa zlozona
	{
		double tacGaInAs = mGa * mGaAs.ac() + mIn * mInAs.ac() - mGa * mIn * 2.61;
		double tacGaInP = mGa * mGaP.ac() + mIn * mInP.ac() /*- mGa * mIn * 0.*/;
		double tacGaAsP = mAs * mGaAs.ac() + mP * mGaP.ac() /*- mAs * mP * 0.*/;
		double tacInAsP = mAs * mInAs.ac() + mP * mInP.ac() /*- mAs * mP * 0.*/;
		return ( (mGa*mIn*(mAs*tacGaInAs+mP*tacGaInP) + (mAs*mP*(mGa*tacGaAsP+mIn*tacInAsP))) / (mGa*mIn+mAs*mP) );
	}
	else return 0.;
}
//------------------------------------------------------------------------------
double GaInAsP::av(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaP, InAs i InP";
	}
	double tavLin = mGa*mAs*mGaAs.av() + mGa*mP*mGaP.av() + mIn*mAs*mInAs.av() + mIn*mP*mInP.av();
	return ( tavLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double GaInAsP::b(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaP, InAs i InP";
	}
	double tbLin = mGa*mAs*mGaAs.b() + mGa*mP*mGaP.b() + mIn*mAs*mInAs.b() + mIn*mP*mInP.b();
	return ( tbLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double GaInAsP::d(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaP, InAs i InP";
	}
	double tdLin = mGa*mAs*mGaAs.d() + mGa*mP*mGaP.d() + mIn*mAs*mInAs.d() + mIn*mP*mInP.d();
	return ( tdLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double GaInAsP::c11(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaP, InAs i InP";
	}
	double tc11Lin = mGa*mAs*mGaAs.c11() + mGa*mP*mGaP.c11() + mIn*mAs*mInAs.c11() + mIn*mP*mInP.c11();
	return ( tc11Lin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double GaInAsP::c12(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaP, InAs i InP";
	}
	double tc12Lin = mGa*mAs*mGaAs.c12() + mGa*mP*mGaP.c12() + mIn*mAs*mInAs.c12() + mIn*mP*mInP.c12();
	return ( tc12Lin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double GaInAsP::c44(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaP, InAs i InP";
	}
	double tc44Lin = mGa*mAs*mGaAs.c44() + mGa*mP*mGaP.c44() + mIn*mAs*mInAs.c44() + mIn*mP*mInP.c44();
	return ( tc44Lin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double GaInAsP::Nc(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "standardowy wzor";
	}
	return ( cFunc::Nc(iT, me()) );
}
//------------------------------------------------------------------------------
double GaInAsP::Nv(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "standardowy wzor";
	}
	return ( cFunc::Nv(iT, mh()) );
}
//------------------------------------------------------------------------------
double GaInAsP::ni(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "standardowy wzor";
	}
	return ( cFunc::ni(iT, me(), mh(), Eg(iT)) );
}
//------------------------------------------------------------------------------
double GaInAsP::k(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaP, InAs i InP";
	}
	return ( 1./(mGa*mAs/mGaAs.k(iT) + mGa*mP/mGaP.k(iT) + mIn*mAs/mInAs.k(iT) + mIn*mP/mInP.k(iT) + mGa*mIn*0.72 + mAs*mP*0.91) ); // 0.91 -> tymczasowo tak jak dla As-Sb
}
//------------------------------------------------------------------------------
double GaInAsP::cp(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaP, InAs i InP";
	}
	double tcpLin = mGa*mAs*mGaAs.cp(iT) + mGa*mP*mGaP.cp(iT) + mIn*mAs*mInAs.cp(iT) + mIn*mP*mInP.cp(iT);
	return ( tcpLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double GaInAsP::g(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaP, InAs i InP";
	}
	double tgLin = mGa*mAs*mGaAs.g(iT) + mGa*mP*mGaP.g(iT) + mIn*mAs*mInAs.g(iT) + mIn*mP*mInP.g(iT);
	return ( tgLin ); // lin = nlin1 = nlin2
}
//---------------------------------------------------------------------------
void GaInAsP::setInt(std::string iInt)
{
	mInt = iInt;
}
//---------------------------------------------------------------------------
GaInAsP::GaInAsP(double iGa,double iAs)
{
	mGa = iGa;
	mIn = 1.-iGa;
	mAs = iAs;
	mP = 1.-mAs;
	mInt = "nlin1";
}
//---------------------------------------------------------------------------
GaInAsP::GaInAsP()
{
}
//---------------------------------------------------------------------------
GaInAsP::~GaInAsP()
{
}
