#include "GaInAsSb.h"
//------------------------------------------------------------------------------
double GaInAsSb::a(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaSb, InAs i InSb";
	}
	return ( mGa*mAs*mGaAs.a(iT) + mGa*mSb*mGaSb.a(iT) + mIn*mAs*mInAs.a(iT) + mIn*mSb*mInSb.a(iT) );
}
//------------------------------------------------------------------------------
double GaInAsSb::Eg(double iT, char iPoint, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaSb, InAs i InSb";
	}
	double tEgLin = mGa*mAs*mGaAs.Eg(iT, iPoint) + mGa*mSb*mGaSb.Eg(iT, iPoint) + mIn*mAs*mInAs.Eg(iT, iPoint) + mIn*mSb*mInSb.Eg(iT, iPoint);
	if (mInt == "lin") // interpolacja liniowa
		return ( tEgLin );
	else if (mInt == "nlin1") // interpolacja nieliniowa prosta
	{
		if (iPoint == 'G') return ( tEgLin - mGa*mIn*mAs*0.477 - mGa*mIn*mSb*0.415 - mGa*mAs*mSb*1.43 - mIn*mAs*mSb*0.67 - mGa*mIn*mAs*mSb*0.75 );
		else if (iPoint == 'X') return ( tEgLin - mGa*mIn*mAs*1.4 - mGa*mIn*mSb*0.33 - mGa*mAs*mSb*1.2 - mIn*mAs*mSb*0.6 );
		else if (iPoint == 'L') return ( tEgLin - mGa*mIn*mAs*0.33 - mGa*mIn*mSb*0.4 - mGa*mAs*mSb*1.2 - mIn*mAs*mSb*0.6 );
		else return 0.;
	}
	else if (mInt == "nlin2") // interpolacja nieliniowa zlozona
	{
		if (iPoint == 'G')
		{
			double tEgGaInAs = mGa * mGaAs.Eg(iT,iPoint) + mIn * mInAs.Eg(iT,iPoint) - mGa * mIn * 0.477;
			double tEgGaInSb = mGa * mGaSb.Eg(iT,iPoint) + mIn * mInSb.Eg(iT,iPoint) - mGa * mIn * 0.415;
			double tEgGaAsSb = mAs * mGaAs.Eg(iT,iPoint) + mSb * mGaSb.Eg(iT,iPoint) - mAs * mSb * 1.43;
			double tEgInAsSb = mAs * mInAs.Eg(iT,iPoint) + mSb * mInSb.Eg(iT,iPoint) - mAs * mSb * 0.67;
			return ( (mGa*mIn*(mAs*tEgGaInAs+mSb*tEgGaInSb-mAs*mSb*0.75) + (mAs*mSb*(mGa*tEgGaAsSb+mIn*tEgInAsSb-mGa*mIn*0.75))) / (mGa*mIn+mAs*mSb) );
		}
		else if (iPoint == 'X')
		{
			double tEgGaInAs = mGa * mGaAs.Eg(iT,iPoint) + mIn * mInAs.Eg(iT,iPoint) - mGa * mIn * 1.4;
			double tEgGaInSb = mGa * mGaSb.Eg(iT,iPoint) + mIn * mInSb.Eg(iT,iPoint) - mGa * mIn * 0.33;
			double tEgGaAsSb = mAs * mGaAs.Eg(iT,iPoint) + mSb * mGaSb.Eg(iT,iPoint) - mAs * mSb * 1.2;
			double tEgInAsSb = mAs * mInAs.Eg(iT,iPoint) + mSb * mInSb.Eg(iT,iPoint) - mAs * mSb * 0.6;
			return ( (mGa*mIn*(mAs*tEgGaInAs+mSb*tEgGaInSb) + (mAs*mSb*(mGa*tEgGaAsSb+mIn*tEgInAsSb))) / (mGa*mIn+mAs*mSb) );
		}
		else if (iPoint == 'L')
		{
			double tEgGaInAs = mGa * mGaAs.Eg(iT,iPoint) + mIn * mInAs.Eg(iT,iPoint) - mGa * mIn * 0.33;
			double tEgGaInSb = mGa * mGaSb.Eg(iT,iPoint) + mIn * mInSb.Eg(iT,iPoint) - mGa * mIn * 0.4;
			double tEgGaAsSb = mAs * mGaAs.Eg(iT,iPoint) + mSb * mGaSb.Eg(iT,iPoint) - mAs * mSb * 1.2;
			double tEgInAsSb = mAs * mInAs.Eg(iT,iPoint) + mSb * mInSb.Eg(iT,iPoint) - mAs * mSb * 0.6;
			return ( (mGa*mIn*(mAs*tEgGaInAs+mSb*tEgGaInSb) + (mAs*mSb*(mGa*tEgGaAsSb+mIn*tEgInAsSb))) / (mGa*mIn+mAs*mSb) );
		}
		else return 0.;
	}
	else return 0.;
}
//------------------------------------------------------------------------------
double GaInAsSb::Eg(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaSb, InAs i InSb";
	}
	double tEgG = Eg(iT, 'G');
	double tEgX = Eg(iT, 'X');
	double tEgL = Eg(iT, 'L');
	if ((tEgG <= tEgX) && (tEgG <= tEgL)) return tEgG;
	else if (tEgX <= tEgL) return tEgX;
	else return tEgL;
}
//------------------------------------------------------------------------------
double GaInAsSb::Dso(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaSb, InAs i InSb";
	}
	double tDsoLin = mGa*mAs*mGaAs.Dso() + mGa*mSb*mGaSb.Dso() + mIn*mAs*mInAs.Dso() + mIn*mSb*mInSb.Dso();
	if (mInt == "lin") // interpolacja liniowa
		return ( tDsoLin );
	else if (mInt == "nlin1") // interpolacja nieliniowa prosta
		return ( tDsoLin - mGa*mIn*mAs*0.15 - mGa*mIn*mSb*0.1 - mGa*mAs*mSb*0.6 - mIn*mAs*mSb*1.2 );
	else if (mInt == "nlin2") // interpolacja nieliniowa zlozona
	{
		double tDsoGaInAs = mGa * mGaAs.Dso() + mIn * mInAs.Dso() - mGa * mIn * 0.15;
		double tDsoGaInSb = mGa * mGaSb.Dso() + mIn * mInSb.Dso() - mGa * mIn * 0.1;
		double tDsoGaAsSb = mAs * mGaAs.Dso() + mSb * mGaSb.Dso() - mAs * mSb * 0.6;
		double tDsoInAsSb = mAs * mInAs.Dso() + mSb * mInSb.Dso() - mAs * mSb * 1.2;
		return ( (mGa*mIn*(mAs*tDsoGaInAs+mSb*tDsoGaInSb) + (mAs*mSb*(mGa*tDsoGaAsSb+mIn*tDsoInAsSb))) / (mGa*mIn+mAs*mSb) );
	}
	else return 0.;
}
//------------------------------------------------------------------------------
double GaInAsSb::me(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaSb, InAs i InSb";
	}
	double tmeLin = mGa*mAs*mGaAs.me() + mGa*mSb*mGaSb.me() + mIn*mAs*mInAs.me() + mIn*mSb*mInSb.me();
	if (mInt == "lin") // interpolacja liniowa
		return ( tmeLin );
	else if (mInt == "nlin1") // interpolacja nieliniowa prosta
		return ( tmeLin - mGa*mIn*mAs*0.008 - mGa*mIn*mSb*0.010 - mGa*mAs*mSb*0.014 - mIn*mAs*mSb*0.027 );
	else if (mInt == "nlin2") // interpolacja nieliniowa zlozona
	{
		double tmeGaInAs = mGa * mGaAs.me() + mIn * mInAs.me() - mGa * mIn * 0.008;
		double tmeGaInSb = mGa * mGaSb.me() + mIn * mInSb.me() - mGa * mIn * 0.010;
		double tmeGaAsSb = mAs * mGaAs.me() + mSb * mGaSb.me() - mAs * mSb * 0.014;
		double tmeInAsSb = mAs * mInAs.me() + mSb * mInSb.me() - mAs * mSb * 0.027;
		return ( (mGa*mIn*(mAs*tmeGaInAs+mSb*tmeGaInSb) + (mAs*mSb*(mGa*tmeGaAsSb+mIn*tmeInAsSb))) / (mGa*mIn+mAs*mSb) );
	}
	else return 0.;
}
//------------------------------------------------------------------------------
double GaInAsSb::mhh(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaSb, InAs i InSb";
	}
	double tmhhLin = mGa*mAs*mGaAs.mhh() + mGa*mSb*mGaSb.mhh() + mIn*mAs*mInAs.mhh() + mIn*mSb*mInSb.mhh();
	return ( tmhhLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double GaInAsSb::mlh(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaSb, InAs i InSb";
	}
	double tmlhLin = mGa*mAs*mGaAs.mlh() + mGa*mSb*mGaSb.mlh() + mIn*mAs*mInAs.mlh() + mIn*mSb*mInSb.mlh();
	if (mInt == "lin") // interpolacja liniowa
		return ( tmlhLin );
	else if (mInt == "nlin1") // interpolacja nieliniowa prosta
		return ( tmlhLin /*- mGa*mIn*mAs*0.*/ - mGa*mIn*mSb*0.015 /*- mGa*mAs*mSb*0.*/ /*- mIn*mAs*mSb*0.*/ );
	else if (mInt == "nlin2") // interpolacja nieliniowa zlozona
	{
		double tmlhGaInAs = mGa * mGaAs.mlh() + mIn * mInAs.mlh() /*- mGa * mIn * 0.*/;
		double tmlhGaInSb = mGa * mGaSb.mlh() + mIn * mInSb.mlh() - mGa * mIn * 0.015;
		double tmlhGaAsSb = mAs * mGaAs.mlh() + mSb * mGaSb.mlh() /*- mAs * mSb * 0.*/;
		double tmlhInAsSb = mAs * mInAs.mlh() + mSb * mInSb.mlh() /*- mAs * mSb * 0.*/;
		return ( (mGa*mIn*(mAs*tmlhGaInAs+mSb*tmlhGaInSb) + (mAs*mSb*(mGa*tmlhGaAsSb+mIn*tmlhInAsSb))) / (mGa*mIn+mAs*mSb) );
	}
	else return 0.;
}
//------------------------------------------------------------------------------
double GaInAsSb::mso(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaSb, InAs i InSb";
	}
	double tmsoLin = mGa*mAs*mGaAs.mso() + mGa*mSb*mGaSb.mso() + mIn*mAs*mInAs.mso() + mIn*mSb*mInSb.mso();
	return ( tmsoLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double GaInAsSb::mh(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "mh = (mlh^3/2+mhh^3/2)^2/3";
	}
	return ( pow(pow(mlh(), 1.5) + pow(mhh(), 1.5), 2./3.) );
}
//------------------------------------------------------------------------------
double GaInAsSb::Ev(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaSb, InAs i InSb";
	}
	double tEvLin = mGa*mAs*mGaAs.Ev() + mGa*mSb*mGaSb.Ev() + mIn*mAs*mInAs.Ev() + mIn*mSb*mInSb.Ev() ;
	if (mInt == "lin") // interpolacja liniowa
		return ( tEvLin );
	else if (mInt == "nlin1") // interpolacja nieliniowa prosta
		return ( tEvLin - mGa*mIn*mAs*(-0.38) /*- mGa*mIn*mSb*0.*/ - mGa*mAs*mSb*(-1.06) /*- mIn*mAs*mSb*0.*/ );
	else if (mInt == "nlin2") // interpolacja nieliniowa zlozona
	{
		double tEvGaInAs = mGa * mGaAs.Ev() + mIn * mInAs.Ev() - mGa * mIn * (-0.38);
		double tEvGaInSb = mGa * mGaSb.Ev() + mIn * mInSb.Ev() /*- mGa * mIn * 0.*/;
		double tEvGaAsSb = mAs * mGaAs.Ev() + mSb * mGaSb.Ev() - mAs * mSb * (-1.06);
		double tEvInAsSb = mAs * mInAs.Ev() + mSb * mInSb.Ev() /*- mAs * mSb * 0.*/;
		return ( (mGa*mIn*(mAs*tEvGaInAs+mSb*tEvGaInSb) + (mAs*mSb*(mGa*tEvGaAsSb+mIn*tEvInAsSb))) / (mGa*mIn+mAs*mSb) );
	}
	else return 0.;
}
//------------------------------------------------------------------------------
double GaInAsSb::Ec(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaSb, InAs i InSb";
	}
	return ( Ev() + Eg(iT) );
}
//------------------------------------------------------------------------------
double GaInAsSb::ac(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaSb, InAs i InSb";
	}
	double tacLin = mGa*mAs*mGaAs.ac() + mGa*mSb*mGaSb.ac() + mIn*mAs*mInAs.ac() + mIn*mSb*mInSb.ac();
	if (mInt == "lin") // interpolacja liniowa
		return ( tacLin );
	else if (mInt == "nlin1") // interpolacja nieliniowa prosta
		return ( tacLin - mGa*mIn*mAs*2.61 /*- mGa*mIn*mSb*0.*/ /*- mGa*mAs*mSb*0.*/ /*- mIn*mAs*mSb*0.*/ );
	else if (mInt == "nlin2") // interpolacja nieliniowa zlozona
	{
		double tacGaInAs = mGa * mGaAs.ac() + mIn * mInAs.ac() - mGa * mIn * 2.61;
		double tacGaInSb = mGa * mGaSb.ac() + mIn * mInSb.ac() /*- mGa * mIn * 0.*/;
		double tacGaAsSb = mAs * mGaAs.ac() + mSb * mGaSb.ac() /*- mAs * mSb * 0.*/;
		double tacInAsSb = mAs * mInAs.ac() + mSb * mInSb.ac() /*- mAs * mSb * 0.*/;
		return ( (mGa*mIn*(mAs*tacGaInAs+mSb*tacGaInSb) + (mAs*mSb*(mGa*tacGaAsSb+mIn*tacInAsSb))) / (mGa*mIn+mAs*mSb) );
	}
	else return 0.;
}
//------------------------------------------------------------------------------
double GaInAsSb::av(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaSb, InAs i InSb";
	}
	double tavLin = mGa*mAs*mGaAs.av() + mGa*mSb*mGaSb.av() + mIn*mAs*mInAs.av() + mIn*mSb*mInSb.av();
	return ( tavLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double GaInAsSb::b(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaSb, InAs i InSb";
	}
	double tbLin = mGa*mAs*mGaAs.b() + mGa*mSb*mGaSb.b() + mIn*mAs*mInAs.b() + mIn*mSb*mInSb.b();
	return ( tbLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double GaInAsSb::d(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaSb, InAs i InSb";
	}
	double tdLin = mGa*mAs*mGaAs.d() + mGa*mSb*mGaSb.d() + mIn*mAs*mInAs.d() + mIn*mSb*mInSb.d();
	return ( tdLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double GaInAsSb::c11(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaSb, InAs i InSb";
	}
	double tc11Lin = mGa*mAs*mGaAs.c11() + mGa*mSb*mGaSb.c11() + mIn*mAs*mInAs.c11() + mIn*mSb*mInSb.c11();
	return ( tc11Lin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double GaInAsSb::c12(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaSb, InAs i InSb";
	}
	double tc12Lin = mGa*mAs*mGaAs.c12() + mGa*mSb*mGaSb.c12() + mIn*mAs*mInAs.c12() + mIn*mSb*mInSb.c12();
	return ( tc12Lin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double GaInAsSb::c44(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaSb, InAs i InSb";
	}
	double tc44Lin = mGa*mAs*mGaAs.c44() + mGa*mSb*mGaSb.c44() + mIn*mAs*mInAs.c44() + mIn*mSb*mInSb.c44();
	return ( tc44Lin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double GaInAsSb::Nc(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "standardowy wzor";
	}
	return ( cFunc::Nc(iT, me()) );
}
//------------------------------------------------------------------------------
double GaInAsSb::Nv(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "standardowy wzor";
	}
	return ( cFunc::Nv(iT, mh()) );
}
//------------------------------------------------------------------------------
double GaInAsSb::ni(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "standardowy wzor";
	}
	return ( cFunc::ni(iT, me(), mh(), Eg(iT)) );
}
//------------------------------------------------------------------------------
double GaInAsSb::k(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaSb, InAs i InSb";
	}
	return ( 1./(mGa*mAs/mGaAs.k(iT) + mGa*mSb/mGaSb.k(iT) + mIn*mAs/mInAs.k(iT) + mIn*mSb/mInSb.k(iT) + mGa*mIn*0.72 + mAs*mSb*0.91) );
}
//------------------------------------------------------------------------------
double GaInAsSb::cp(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaSb, InAs i InSb";
	}
	double tcpLin = mGa*mAs*mGaAs.cp(iT) + mGa*mSb*mGaSb.cp(iT) + mIn*mAs*mInAs.cp(iT) + mIn*mSb*mInSb.cp(iT);
	return ( tcpLin ); // lin = nlin1 = nlin2
}
//------------------------------------------------------------------------------
double GaInAsSb::g(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaAs, GaSb, InAs i InSb";
	}
	double tgLin = mGa*mAs*mGaAs.g(iT) + mGa*mSb*mGaSb.g(iT) + mIn*mAs*mInAs.g(iT) + mIn*mSb*mInSb.g(iT);
	return ( tgLin ); // lin = nlin1 = nlin2
}
//---------------------------------------------------------------------------
void GaInAsSb::setInt(std::string iInt)
{
	mInt = iInt;
}
//---------------------------------------------------------------------------
GaInAsSb::GaInAsSb(double iGa,double iAs)
{
	mGa = iGa;
	mIn = 1.-iGa;
	mAs = iAs;
	mSb = 1.-mAs;
	mInt = "nlin1";
}
//---------------------------------------------------------------------------
GaInAsSb::GaInAsSb()
{
}
//---------------------------------------------------------------------------
GaInAsSb::~GaInAsSb()
{
}
