#include "GaInSb.h"
//------------------------------------------------------------------------------
double GaInSb::a(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaSb i InSb";
	}
	return ( mGa * mGaSb.a(iT) + mIn * mInSb.a(iT) );
}
//------------------------------------------------------------------------------
double GaInSb::Eg(double iT, char iPoint, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaSb i InSb";
	}
	if (iPoint == 'G') return ( mGa * mGaSb.Eg(iT,iPoint) + mIn * mInSb.Eg(iT,iPoint) - mGa * mIn * 0.415 );
	else if (iPoint == 'X') return ( mGa * mGaSb.Eg(iT,iPoint) + mIn * mInSb.Eg(iT,iPoint) - mGa * mIn * 0.33 );
	else if (iPoint == 'L') return ( mGa * mGaSb.Eg(iT,iPoint) + mIn * mInSb.Eg(iT,iPoint) - mGa * mIn * 0.4 );
	else return 0.;
}
//------------------------------------------------------------------------------
double GaInSb::Eg(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaSb i InSb";
	}
	double tEgG = Eg(iT, 'G');
	double tEgX = Eg(iT, 'X');
	double tEgL = Eg(iT, 'L');
	if ((tEgG <= tEgX) && (tEgG <= tEgL)) return tEgG;
	else if (tEgX <= tEgL) return tEgX;
	else return tEgL;
}
//------------------------------------------------------------------------------
double GaInSb::Dso(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaSb i InSb";
	}
	return ( mGa * mGaSb.Dso() + mIn * mInSb.Dso() - mGa * mIn * 0.1 );
}
//------------------------------------------------------------------------------
double GaInSb::me(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaSb i InSb";
	}
	return ( mGa * mGaSb.me() + mIn * mInSb.me() - mGa * mIn * 0.010 );
}
//------------------------------------------------------------------------------
double GaInSb::mhh(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaSb i InSb";
	}
	return ( mGa * mGaSb.mhh() + mIn * mInSb.mhh() );
}
//------------------------------------------------------------------------------
double GaInSb::mlh(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaSb i InSb";
	}
	return ( mGa * mGaSb.mlh() + mIn * mInSb.mlh() - mGa * mIn * 0.015 );
}
//------------------------------------------------------------------------------
double GaInSb::mso(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaSb i InSb";
	}
	return ( mGa * mGaSb.mso() + mIn * mInSb.mso() );
}
//------------------------------------------------------------------------------
double GaInSb::mh(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "mh = (mlh^3/2+mhh^3/2)^2/3";
	}
	return ( pow(pow(mlh(), 1.5) + pow(mhh(), 1.5), 2./3.) );
}
//------------------------------------------------------------------------------
double GaInSb::Ev(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaSb i InSb";
	}
	return ( mGa * mGaSb.Ev() + mIn * mInSb.Ev() );
}
//------------------------------------------------------------------------------
double GaInSb::Ec(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaSb i InSb";
	}
	return ( Ev() + Eg(iT) );
}
//------------------------------------------------------------------------------
double GaInSb::ac(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaSb i InSb";
	}
	return ( mGa * mGaSb.ac() + mIn * mInSb.ac() );
}
//------------------------------------------------------------------------------
double GaInSb::av(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaSb i InSb";
	}
	return ( mGa * mGaSb.av() + mIn * mInSb.av() );
}
//------------------------------------------------------------------------------
double GaInSb::b(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaSb i InSb";
	}
	return ( mGa * mGaSb.b() + mIn * mInSb.b() );
}
//------------------------------------------------------------------------------
double GaInSb::d(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaSb i InSb";
	}
	return ( mGa * mGaSb.d() + mIn * mInSb.d() );
}
//------------------------------------------------------------------------------
double GaInSb::c11(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaSb i InSb";
	}
	return ( mGa * mGaSb.c11() + mIn * mInSb.c11() );
}
//------------------------------------------------------------------------------
double GaInSb::c12(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaSb i InSb";
	}
	return ( mGa * mGaSb.c12() + mIn * mInSb.c12() );
}
//------------------------------------------------------------------------------
double GaInSb::c44(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaSb i InSb";
	}
	return ( mGa * mGaSb.c44() + mIn * mInSb.c44() );
}
//------------------------------------------------------------------------------
double GaInSb::Nc(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "standardowy wzor";
	}
	return ( cFunc::Nc(iT, me()) );
}
//------------------------------------------------------------------------------
double GaInSb::Nv(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "standardowy wzor";
	}
	return ( cFunc::Nv(iT, mh()) );
}
//------------------------------------------------------------------------------
double GaInSb::ni(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "standardowy wzor";
	}
	return ( cFunc::ni(iT, me(), mh(), Eg(iT)) );
}
//------------------------------------------------------------------------------
double GaInSb::k(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaSb i InSb";
	}
	return ( 1./(mGa/mGaSb.k(iT) + mIn/mInSb.k(iT) + mGa*mIn*0.72) );
}
//------------------------------------------------------------------------------
double GaInSb::cp(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaSb i InSb";
	}
	return ( mGa * mGaSb.cp(iT) + mIn * mInSb.cp(iT) );
}
//------------------------------------------------------------------------------
double GaInSb::g(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaSb i InSb";
	}
	return ( mGa * mGaSb.g(iT) + mIn * mInSb.g(iT) );
}
//---------------------------------------------------------------------------
GaInSb::GaInSb(double iGa)
{
	mGa = iGa;
	mIn = 1.-iGa;
}
//---------------------------------------------------------------------------
GaInSb::GaInSb()
{
}
//---------------------------------------------------------------------------
GaInSb::~GaInSb()
{
}
