#include "GaPSb.h"
//------------------------------------------------------------------------------
double GaPSb::a(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaP i GaSb";
	}
	return ( mP * mGaP.a(iT) + mSb * mGaSb.a(iT) );
}
//------------------------------------------------------------------------------
double GaPSb::Eg(double iT, char iPoint, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaP i GaSb";
	}
	if (iPoint == 'G') return ( mP * mGaP.Eg(iT,iPoint) + mSb * mGaSb.Eg(iT,iPoint) - mP * mSb * 2.7 );
	else if (iPoint == 'X') return ( mP * mGaP.Eg(iT,iPoint) + mSb * mGaSb.Eg(iT,iPoint) - mP * mSb * 2.7 );
	else if (iPoint == 'L') return ( mP * mGaP.Eg(iT,iPoint) + mSb * mGaSb.Eg(iT,iPoint) - mP * mSb * 2.7 );
	else return 0.;
}
//------------------------------------------------------------------------------
double GaPSb::Eg(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaP i GaSb";
	}
	double tEgG = Eg(iT, 'G');
	double tEgX = Eg(iT, 'X');
	double tEgL = Eg(iT, 'L');
	if ((tEgG <= tEgX) && (tEgG <= tEgL)) return tEgG;
	else if (tEgX <= tEgL) return tEgX;
	else return tEgL;
}
//------------------------------------------------------------------------------
double GaPSb::Dso(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaP i GaSb";
	}
	return ( mP * mGaP.Dso() + mSb * mGaSb.Dso() );
}
//------------------------------------------------------------------------------
double GaPSb::me(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaP i GaSb";
	}
	return ( mP * mGaP.me() + mSb * mGaSb.me() );
}
//------------------------------------------------------------------------------
double GaPSb::mhh(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaP i GaSb";
	}
	return ( mP * mGaP.mhh() + mSb * mGaSb.mhh() );
}
//------------------------------------------------------------------------------
double GaPSb::mlh(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaP i GaSb";
	}
	return ( mP * mGaP.mlh() + mSb * mGaSb.mlh() );
}
//------------------------------------------------------------------------------
double GaPSb::mso(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaP i GaSb";
	}
	return ( mP * mGaP.mso() + mSb * mGaSb.mso() );
}
//------------------------------------------------------------------------------
double GaPSb::mh(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "mh = (mlh^3/2+mhh^3/2)^2/3";
	}
	return ( pow(pow(mlh(), 1.5) + pow(mhh(), 1.5), 2./3.) );
}
//------------------------------------------------------------------------------
double GaPSb::Ev(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaP i GaSb";
	}
	return ( mP * mGaP.Ev() + mSb * mGaSb.Ev() );
}
//------------------------------------------------------------------------------
double GaPSb::Ec(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaP i GaSb";
	}
	return ( Ev() + Eg(iT) );
}
//------------------------------------------------------------------------------
double GaPSb::ac(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaP i GaSb";
	}
	return ( mP * mGaP.ac() + mSb * mGaSb.ac() );
}
//------------------------------------------------------------------------------
double GaPSb::av(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaP i GaSb";
	}
	return ( mP * mGaP.av() + mSb * mGaSb.av() );
}
//------------------------------------------------------------------------------
double GaPSb::b(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaP i GaSb";
	}
	return ( mP * mGaP.b() + mSb * mGaSb.b() );
}
//------------------------------------------------------------------------------
double GaPSb::d(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaP i GaSb";
	}
	return ( mP * mGaP.d() + mSb * mGaSb.d() );
}
//------------------------------------------------------------------------------
double GaPSb::c11(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaP i GaSb";
	}
	return ( mP * mGaP.c11() + mSb * mGaSb.c11() );
}
//------------------------------------------------------------------------------
double GaPSb::c12(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaP i GaSb";
	}
	return ( mP * mGaP.c12() + mSb * mGaSb.c12() );
}
//------------------------------------------------------------------------------
double GaPSb::c44(reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "I. Vurgaftman, J. R. Meyer, and L. R. Ram-Mohan";
		ipRef->title = "Band parameters for III-V compound semiconductors and their alloys";
		ipRef->journal = "Journal of Applied Physics, vol. 89, no. 11, pp. 5815-5875, 2001";
		ipRef->comment = "wartosc interpolowana z danych dla GaP i GaSb";
	}
	return ( mP * mGaP.c44() + mSb * mGaSb.c44() );
}
//------------------------------------------------------------------------------
double GaPSb::Nc(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "standardowy wzor";
	}
	return ( cFunc::Nc(iT, me()) );
}
//------------------------------------------------------------------------------
double GaPSb::Nv(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "standardowy wzor";
	}
	return ( cFunc::Nv(iT, mh()) );
}
//------------------------------------------------------------------------------
double GaPSb::ni(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "-";
		ipRef->title = "-";
		ipRef->journal = "-";
		ipRef->comment = "standardowy wzor";
	}
	return ( cFunc::ni(iT, me(), mh(), Eg(iT)) );
}
//------------------------------------------------------------------------------
double GaPSb::k(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaP i GaSb";
	}
	return ( 1./(mP/mGaP.k(iT) + mSb/mGaSb.k(iT) + mP*mSb*0.91) ); // 0.91 -> tymczasowo tak jak dla As-Sb
}
//------------------------------------------------------------------------------
double GaPSb::cp(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaP i GaSb";
	}
	return ( mP * mGaP.cp(iT) + mSb * mGaSb.cp(iT) );
}
//------------------------------------------------------------------------------
double GaPSb::g(double iT, reference *ipRef)
{
	if(ipRef!=NULL)
	{
		ipRef->reset();
		ipRef->author = "S. Adachi";
		ipRef->title = "Properties of Semiconductors Alloys";
		ipRef->journal = "John Wiley and Sons, 2009";
		ipRef->comment = "wartosc interpolowana z danych dla GaP i GaSb";
	}
	return ( mP * mGaP.g(iT) + mSb * mGaSb.g(iT) );
}
//------------------------------------------------------------------------------
GaPSb::GaPSb(double iP)
{
	mP = iP;
	mSb = 1.-iP;
}
//------------------------------------------------------------------------------
GaPSb::GaPSb()
{
}
//------------------------------------------------------------------------------
GaPSb::~GaPSb()
{
}
//------------------------------------------------------------------------------
