/*##############################################################################
#                                                                              #
# klasa obslugujaca baze materialowa                                           #
#                                                                              #
# data utworzenia pliku: 04-12-2005						                       #
# data ostatniej modyfikacji: 17-04-2014                                       #
# autorzy kodu: KRZYSZTOF GUTOWSKI (kgutek@gmail.com)                          #
#               LUKASZ PISKORSKI (lukasz.piskorski@p.lodz.pl)                  #
#                                                                              #
##############################################################################*/

/*##############################################################################
#                                                                              #
# materialy znajdujace sie w bazie:                                            #
#                                                                              #
# GaAs, AlAs, InAs, AlGaAs, InGaAs, AlInAs, AlGaInAs                           #
# InP, GaP, AlP, GaInP, AlInP, AlGaP, AlGaInP                                  #
# GaSb, InSb, AlSb, GaInSb, AlInSb, AlGaSb                                     #
# GaAsSb, InAsSb, AlAsSb, GaInAsSb, AlGaAsSb                                   #
# GaAsP, InAsP, AlAsP, GaInAsP                                                 #
# GaPSb, InPSb, AlPSb                                                          #
# GaN, AlN, InN, AlGaN, InGaN, InAlGaN (struktura wurcytu)                     #
# GaN, AlN, InN, GaNAs, GaInNAs, GaInNAsSb (struktura blendy cynkowej)         #
# c-Si                                                                         #
# a-Si, a-SiO2, AlxOy, ITO, diament, powietrze, BCB (benzocyklobutan)          #
# Ti, Au, Pt, Cu, Ni, Ag, Al, Be, Cr, Pd, W, In, AuGe                          #
#                                                                              #
##############################################################################*/

/*##############################################################################
#                                                                              #
# parametry:                                                                   #
# a(A) - lattice_constant                                                      #
# c(A) - lattice_constant_c                                                    #
# chi(eV) - electron_affinity                                                  #
# Eg(eV) - energy_gap                                                          #
# Dso(eV) - split_off_energy	                                               #
# me(m0) - electron_effective_mass                                             #
# mhh(m0) - heavy_hole_effective_mass                                          #
# mlh(m0) - light_hole_effective_mass                                          #
# meL(m0) - electron_effective_mass_longitudinal                               #
# meT(m0) - electron_effective_mass_transversal                                #
# mhhL(m0) - heavy_hole_effective_mass_longitudinal                            #
# mhhT(m0) - heavy_hole_effective_mass_transversal                             #
# mlhL(m0) - light_hole_effective_mass_longitudinal                            #
# mlhT(m0) - light_hole_effective_mass_transversal                             #
# mso(m0) - split_off_hole_mass                                                #
# mh(m0) - hole_effective_mass                                                 #
# Ev(eV) - valence_band_edge                                                   #
# Ec(eV) - conduction_band_edge                                                #
# ac(eV) - deformation_potential_ac                                            #
# av(eV) - deformation_potential_av                                            #
# b(eV) - deformation_potential_b                                              #
# d(eV) - deformation_potential_d                                              #
# c11(GPa) - elastic_constant_c11                                              #
# c12(GPa - elastic_constant_c12                                               #
# c13(GPa) - elastic_constant_c13                                              #
# c33(GPa) - elastic_constant_c33                                              #
# c44(GPa) - elastic_constant_c44                                              #
# d13(pm/V) - piezoelectric_coefficient_d13                                    #
# d15(pm/V) - piezoelectric_coefficient_d15                                    #
# d33(pm/V) - piezoelectric_coefficient_d33                                    #
# e15(C/m^2) - piezoelectric_coefficient_e15                                   #
# e31(C/m^2) - piezoelectric_coefficient_e31                                   #
# e33(C/m^2) - piezoelectric_coefficient_e33                                   #
# Psp(C/m^2) - spontaneous_polarization                                        #
# Nc(1/m^3) - effective_density_of_states_in_the_conduction_band               #
# Nv(1/m^3) - effective_density_of_states_in_the_valence_band                  #
# ni(1/m^3) - intrinsic_carrier_concentration                                  #
# Eact(eV) - activation energy                                                 #
# n(1/m^3) - free_carrier_concentration                                        #
# mi(m^2/(V*s)) - mobility                                                     #
# sigma(S/m) - electrical_conductivity                                         #
# rho(Om*m) - electrical_resistivity                                           #
# k(W/(m*K)) - thermal_conductivity                                            #
# cp(J/(kg*K)) - specific_heat                                                 #
# g(J/(kg*K)) - density                                                        #
# epsR(-) - dielectric_constant                                                #
# nR(-) - refractive_index                                                     #
# alfa(cm^-1) - absorption                                                     #
#                                                                              #
##############################################################################*/

/* Historia zmian od 27.02.2006

17.04.2014 Lukasz Piskorski
		   nowy parametr: energia aktywacji

18.01.2014 Lukasz Piskorski
		   nowe metale: Ag, Al, Be, Cr, Pd, W

17.01.2014 Lukasz Piskorski
		   nowy material: BCB (benzocyklobutan)

17.12.2013 Lukasz Piskorski
		   nowe parametry: cieplo wlasciwe i gestosc
		   nowy material: powietrze

14.12.2013 Lukasz Piskorski
		   masy efektywne dla InAlGaN

09.12.2013 Lukasz Piskorski
		   nowe materialy: GaInAsSb, AlGaAsSb, GaInAsP, GaInNAs, GaN (zb), AlN (zb), InN (zb)

07.12.2013 Lukasz Piskorski
		   nowe materialy: GaP, AlP, AlSb, InSb, GaInSb, AlInSb, AlGaSb, GaAsSb, InAsSb, AlAsSb, GaAsP, InAsP, AlAsP, GaPSb, InPSb, AlPSb
		   nowe parametry: ac, av, b, d, c11, c12, c44 - do liczenia efektow zwiazanych z naprezeniami

02.12.2013 Lukasz Piskorski
		   nowe materialy: amorficzny SiO2, amorficzny Si, AlInAs, AlAsSb
		   poprawki w materialach: AlGaAs, InP, InGaAs, GaSb - usuniecie "_v2"; GaInP - nowe ruchliwosci
		   dodatkowe (krotsze) wywolania parametrow
		   nieuzywane funkcje zostaly usuniete 

21.11.2013 Lukasz Piskorski
		   nowy material: AlGaAs_g
		   nowe funkcje: double thermal_conductivity(double T, char iDir, reference *ref_ptr)
						 double electrical_conductivity(double T, char iDir, reference *ref_ptr)

02.06.2013 Robert Sarzala
		   nowy material: ITO, transparent contact
		   nowe funkcje: double thermal_conductivity(double T, reference *ref_ptr)
						 double electrical_conductivity(double T, reference *ref_ptr)
						 double refraction_index(double lambda, reference *ref_ptr)
						 double absorption(double lambda, reference *ref_ptr)

08.05.2013 Maciej Kuc
           aktualizacja parametrw dla materiaw azotkowych oraz diamentu
           nowe funkcje: double thermal_conductivity(double T, double p, std::string dopant, reference *ref_ptr)
						 double refraction_index(double lambda, double T, double N, std::string dopant, reference *ref_ptr)

22.04.2013 Lukasz Piskorski
           nowy materia: cSi (krystaliczny krzem)

15.03.2013 Lukasz Piskorski
           nowy materialy: AlGaN_T, InGaN_T (parametry optyczne skopiowane z pliku MaterialData - patrz rozpr. dokt. Tomasza Czyszanowskiego)

15.05.2012 Lukasz Piskorski
           nowy materialy: InP_v2, GaInAs_v2, GaSb_v2 (nowe sposoby wyznaczania koncentacji swobodnych nosnikow ruchliwosci,
                           przewodnosci elektrycznej, absorpcji; innych parametrw dla tego materiau nie liczy)

14.05.2012 Lukasz Piskorski
           nowy material: AlGaAs_v2 (nowe sposoby wyznaczania koncentacji swobodnych nosnikow ruchliwosci, przewodnosci elektrycznej,
                          absorpcji; innych parametrw dla tego materiau nie liczy)

21.04.2009 Lukasz Piskorski
           nowy material: material testowy test02 

16.04.2009 Lukasz Piskorski
           poprawki w wywolaniach funkcji

 7.04.2009 Lukasz Piskorski
           aktualizacja parametrow dla: AlGaInAs 
           nowy material: material testowy test01 
 
11.12.2008 Lukasz Piskorski
           aktualizacja parametrow dla: InP 
 
10.12.2008 Lukasz Piskorski
           aktualizacja parametrow dla: Ti, Pt, Au, Ni, Cu, AuGe, In
           nowe funkcje:  double electrical_resistivity(double T, reference *ref_ptr=NULL);
                          double hole_effective_mass(reference *ref_ptr=NULL);
                          double split_off_hole_mass(reference *ref_ptr=NULL);
                          
18.09.2008 Lukasz Piskorski
           nowe funkcje:  double donor_ionization_energy(std::string,reference *ref_ptr=NULL);
                          double acceptor_ionization_energy(std::string,reference *ref_ptr=NULL);
                          double effective_density_of_states_in_the_valence_band(double,reference *ref_ptr=NULL);
                          
 3.09.2008 Lukasz Piskorski
           nowe funkcje:  double effective_density_of_states_in_the_conduction_band(double,reference *ref_ptr=NULL);
                          double effective_density_of_states_in_the_valence_band(double,reference *ref_ptr=NULL);
                          double dielectric_constant(reference * ref_ptr=NULL);
                          double electron_affinity(reference * ref_ptr=NULL)
                          double intrinsic_carrier_concentration(double,reference *ref_ptr=NULL);

16.06.2008 Lukasz Piskorski
           nowe materialy: InP, AlGaInAs
           nowe funkcje:  double valance_band_offset(reference * ref_ptr=NULL);
                          double conduction_band_offset(double,reference * ref_ptr=NULL);

27.02.2006 Piotr Karbownik
           nowe materialy: AlN, InN
           uzupelnienia azotkow : InAlGaN,AlGaN,InGaN
           nowe funkcje : electron_effective_mass_longitudinal(reference *ref_ptr=NULL);
                          electron_effective_mass_transversal(reference *ref_ptr=NULL)
                          heavy_hole_effective_mass_longitudinal(reference *ref_ptr=NULL);
                          double light_hole_effective_mass_longitudinal(reference *ref_ptr=NULL);
                          double heavy_hole_effective_mass_transversal(reference *ref_ptr=NULL);
                          double light_hole_effective_mass_transversal(reference *ref_ptr=NULL);
                          double thermal_conductivity(double,double, reference * ref_ptr=NULL); [k], [m^-3]   
*/

#ifndef material_interface_h
#define material_interface_h

#include "./MaterialDataBase/AlGaAs.h"		// Al(x)Ga(1-x)As/AlAs/GaAs
#include "./MaterialDataBase/AlGaAs_g.h"	// Al(x)Ga(1-x)As_g
#include "./MaterialDataBase/InGaAs.h"		// In(x)Ga(1-x)As/InAs
#include "./MaterialDataBase/AlInAs.h"		// Al(x)In(1-x)As
#include "./MaterialDataBase/AlGaInAs.h"	// Al(x)Ga(x)In(1-x-y)As

#include "./MaterialDataBase/AlP.h"			// AlP
#include "./MaterialDataBase/GaP.h"			// GaP
#include "./MaterialDataBase/InP.h"			// InP
#include "./MaterialDataBase/AlGaP.h"		// Al(x)Ga(1-x)P
#include "./MaterialDataBase/AlInP.h"		// Al(x)In(1-x)P
#include "./MaterialDataBase/GaInP.h"		// Ga(x)In(1-x)P
#include "./MaterialDataBase/AlGaInP.h"		// Al(x)Ga(y)In(1-x-y)P

#include "./MaterialDataBase/AlAsP.h"		// AlAs(x)P(1-x)
#include "./MaterialDataBase/GaAsP.h"		// GaAs(x)P(1-x)
#include "./MaterialDataBase/InAsP.h"		// InAs(x)P(1-x)
#include "./MaterialDataBase/GaInAsP.h"		// Ga(x)In(1-x)As(y)P(1-y)

#include "./MaterialDataBase/AlSb.h"		// AlSb
#include "./MaterialDataBase/GaSb.h"		// GaSb
#include "./MaterialDataBase/InSb.h"		// InSb
#include "./MaterialDataBase/AlInSb.h"		// Al(x)In(1-x)Sb
#include "./MaterialDataBase/GaInSb.h"		// Ga(x)In(1-x)Sb
#include "./MaterialDataBase/AlGaSb.h"		// Al(x)Ga(1-x)Sb

#include "./MaterialDataBase/AlAsSb.h"		// AlAs(x)Sb(1-x)
#include "./MaterialDataBase/GaAsSb.h"		// GaAs(x)Sb(1-x)
#include "./MaterialDataBase/InAsSb.h"		// InAs(x)Sb(1-x)
#include "./MaterialDataBase/GaInAsSb.h"	// Ga(x)In(1-x)As(y)Sb(1-y)
#include "./MaterialDataBase/AlGaAsSb.h"	// Al(x)Ga(1-x)As(y)Sb(1-y)

#include "./MaterialDataBase/AlPSb.h"		// AlP(x)Sb(1-x)
#include "./MaterialDataBase/GaPSb.h"		// GaP(x)Sb(1-x)
#include "./MaterialDataBase/InPSb.h"		// InP(x)Sb(1-x)

#include "./MaterialDataBase/GaN.h"			// GaN
#include "./MaterialDataBase/AlN.h"			// AlN
#include "./MaterialDataBase/InN.h"			// InN
#include "./MaterialDataBase/AlGaN.h"		// Al(x)Ga(1-x)N
#include "./MaterialDataBase/InGaN.h"		// In(x)Ga(1-x)N
#include "./MaterialDataBase/InAlGaN.h"		// In(x)Al(y)Ga(1-x-y)N

#include "./MaterialDataBase/GaN_Si.h"		// Si-doped GaN	TODO
#include "./MaterialDataBase/GaN_Mg.h"		// Mg-doped GaN TODO
#include "./MaterialDataBase/Al5GaN_Si.h"	// Si-doped Al5GaN TODO
#include "./MaterialDataBase/Al5GaN_Mg.h"	// Mg-doped Al5GaN TODO
#include "./MaterialDataBase/Al10GaN_Si.h"	// Si-doped Al10GaN	TODO
#include "./MaterialDataBase/Al10GaN_Mg.h"	// Mg-doped Al10GaN	TODO
#include "./MaterialDataBase/Al30GaN_Mg.h"	// Mg-doped Al30GaN	TODO
#include "./MaterialDataBase/In10GaN_Si.h"	// Si-doped In10GaN	TODO

#include "./MaterialDataBase/GaNzb.h"		// GaN (zb)
#include "./MaterialDataBase/AlNzb.h"		// AlN (zb)
#include "./MaterialDataBase/InNzb.h"		// InN (zb)
#include "./MaterialDataBase/GaNAs.h"		// GaN(x)As(1-x) TODO
#include "./MaterialDataBase/GaInNAs.h"		// Ga(x)In(1-x)N(y)As(1-y)
#include "./MaterialDataBase/GaInNAsSb.h"	// GaIn(x)N(y)As(1-y-z)Sb(z) TODO

#include "./MaterialDataBase/ITO.h"			// ITO
#include "./MaterialDataBase/cSi.h"			// cSi
#include "./MaterialDataBase/aSi.h"			// amorficzny Si
#include "./MaterialDataBase/aSiO2.h"		// amorficzny SiO2
#include "./MaterialDataBase/AlxOy.h"		// utleniony AlAs
#include "./MaterialDataBase/diament.h"		// diament
#include "./MaterialDataBase/BCB.h"			// BCB (benzocyklobutan)
#include "./MaterialDataBase/powietrze.h"	// powietrze

#include "./MaterialDataBase/Ti.h"			// Ti
#include "./MaterialDataBase/Au.h"			// Au
#include "./MaterialDataBase/Pt.h"			// Pt
#include "./MaterialDataBase/Cu.h"			// Cu
#include "./MaterialDataBase/Ni.h"			// Ni
#include "./MaterialDataBase/Ag.h"			// Ag
#include "./MaterialDataBase/Al.h"			// Al
#include "./MaterialDataBase/Be.h"			// Be
#include "./MaterialDataBase/Cr.h"			// Cr
#include "./MaterialDataBase/Pd.h"			// Pd
#include "./MaterialDataBase/W.h"			// W
#include "./MaterialDataBase/In.h"			// In
#include "./MaterialDataBase/AuGe.h"		// AuGe

#include "./MaterialDataBase/test01.h"		// material testowy 01 TODO
#include "./MaterialDataBase/test02.h"		// material testowy 02 TODO

class material_interface
{
	private: 
		material *mpMat; // wskaznik do materialu

	public:
/* a(A) */			double lattice_constant(double iT, reference *ipRef=NULL) {	return mpMat->a(iT, ipRef); } // T(K)
/* c(A) */			double lattice_constant_c(double iT, reference *ipRef=NULL) { return mpMat->c(iT, ipRef); } // T(K)
/* chi(eV) */		double electron_affinity(reference *ipRef=NULL) { return mpMat->ea(ipRef); }
/* Eg(eV) */		double energy_gap(double iT, char iPoint, reference *ipRef=NULL) { return mpMat->Eg(iT, iPoint, ipRef); } // T(K), point(-)
/* Eg(eV) */		double energy_gap(double iT, reference *ipRef=NULL) { return mpMat->Eg(iT, ipRef); } // T(K)
/* Dso(eV) */		double split_off_energy(reference *ipRef=NULL) { return mpMat->Dso(ipRef); }
/* me(m0) */		double electron_effective_mass(reference *ipRef=NULL) { return mpMat->me(ipRef); }
/* mhh(m0) */		double heavy_hole_effective_mass(reference *ipRef=NULL) { return mpMat->mhh(ipRef); }
/* mlh(m0) */		double light_hole_effective_mass(reference *ipRef=NULL) { return mpMat->mlh(ipRef); }
/* meL(m0) */		double electron_effective_mass_longitudinal(reference *ipRef=NULL) { return mpMat->meL(ipRef); }
/* meT(m0) */		double electron_effective_mass_transversal(reference *ipRef=NULL) { return mpMat->meT(ipRef); }
/* mhhL(m0) */		double heavy_hole_effective_mass_longitudinal(reference *ipRef=NULL) { return mpMat->mhhL(ipRef); }
/* mhhT(m0) */		double heavy_hole_effective_mass_transversal(reference *ipRef=NULL) { return mpMat->mhhT(ipRef); }
/* mlhL(m0) */		double light_hole_effective_mass_longitudinal(reference *ipRef=NULL) { return mpMat->mlhL(ipRef); }
/* mlhT(m0) */		double light_hole_effective_mass_transversal(reference *ipRef=NULL) { return mpMat->mlhT(ipRef); }
/* mso(m0) */		double split_off_hole_mass(reference *ipRef=NULL) { return mpMat->mso(ipRef); }
/* mh(m0) */		double hole_effective_mass(reference *ipRef=NULL) { return mpMat->mh(ipRef); }
/* Ev(eV) */		double valence_band_edge(reference *ipRef=NULL) { return mpMat->Ev(ipRef); }
/* Ec(eV) */		double conduction_band_edge(double iT, reference *ipRef=NULL) { return mpMat->Ec(iT, ipRef); } // T(K)
/* ac(eV) */		double deformation_potential_ac(reference *ipRef=NULL) { return mpMat->ac(ipRef); }
/* av(eV) */		double deformation_potential_av(reference *ipRef=NULL) { return mpMat->av(ipRef); }
/* b(eV) */			double deformation_potential_b(reference *ipRef=NULL) { return mpMat->b(ipRef); }
/* d(eV) */			double deformation_potential_d(reference *ipRef=NULL) { return mpMat->d(ipRef); }
/* c11(GPa) */		double elastic_constant_c11(reference *ipRef=NULL) { return mpMat->c11(ipRef); }
/* c12(GPa) */		double elastic_constant_c12(reference *ipRef=NULL) { return mpMat->c12(ipRef); }
/* c13(GPa) */		double elastic_constant_c13(reference *ipRef=NULL) { return mpMat->c13(ipRef); }
/* c33(GPa) */		double elastic_constant_c33(reference *ipRef=NULL) { return mpMat->c33(ipRef); }
/* c44(GPa) */		double elastic_constant_c44(reference *ipRef=NULL) { return mpMat->c44(ipRef); }
/* d13(pm/V) */		double piezoelectric_coefficient_d13(reference *ipRef=NULL) { return mpMat->d13(ipRef); }
/* d15(pm/V) */		double piezoelectric_coefficient_d15(reference *ipRef=NULL) { return mpMat->d15(ipRef); }
/* d33(pm/V) */		double piezoelectric_coefficient_d33(reference *ipRef=NULL) { return mpMat->d33(ipRef); }
/* e15(C/m^2) */	double piezoelectric_coefficient_e15(reference *ipRef=NULL) { return mpMat->e15(ipRef); }
/* e31(C/m^2) */	double piezoelectric_coefficient_e31(reference *ipRef=NULL) { return mpMat->e31(ipRef); }
/* e33(C/m^2) */	double piezoelectric_coefficient_e33(reference *ipRef=NULL) { return mpMat->e33(ipRef); }
/* Psp(C/m^2) */	double spontaneous_polarization(reference *ipRef=NULL) { return mpMat->Psp(ipRef); }
/* Nc(1/m^3) */		double effective_density_of_states_in_the_conduction_band(double iT, reference *ipRef=NULL) { return mpMat->Nc(iT, ipRef); } // T(K)
/* Nv(1/m^3) */		double effective_density_of_states_in_the_valence_band(double iT, reference *ipRef=NULL) { return mpMat->Nv(iT, ipRef); } // T(K)
/* ni(1/m^3) */		double intrinsic_carrier_concentration(double iT, reference *ipRef=NULL) { return mpMat->ni(iT, ipRef); } // T(K)
/* Eact(eV) */		double activation_energy(std::string iDop, reference *ipRef=NULL) { return mpMat->Eact(iDop, ipRef); } // N(1/m^3), Dop(-)
/* Eact(eV) */		double activation_energy(double iN, std::string iDop, reference *ipRef=NULL) { return mpMat->Eact(iN, iDop, ipRef); } // Dop(-)
/* n(1/m^3) */		double free_carrier_concentration(double iT, double iN, std::string iDop, reference *ipRef=NULL) { return mpMat->n(iT, iN, iDop, ipRef); } // T(K), N(1/m^3), Dop(-)
/* mi(m^2/(V*s)) */	double mobility(double iT, double iN, std::string iDop, reference *ipRef=NULL) { return mpMat->mob(iT, iN, iDop, ipRef); } // T(K), N(1/m^3), Dop(-)
/* sigma(S/m) */	double electrical_conductivity(double iT, double iN, std::string iDop, char iDir, reference *ipRef=NULL) { return mpMat->ec(iT, iN, iDop, iDir, ipRef); } // T(K), N(1/m^3), Dop(-), dir(-)
/* sigma(S/m) */	double electrical_conductivity(double iT, double iN, std::string iDop, reference *ipRef=NULL) { return mpMat->ec(iT, iN, iDop, ipRef); } // T(K), N(1/m^3), Dop(-)
/* sigma(S/m) */	double electrical_conductivity(double iT, reference *ipRef=NULL) { return mpMat->ec(iT, ipRef); } // T(K)
/* rho(Om*m) */		double electrical_resistivity(double iT, reference *ipRef=NULL) { return mpMat->er(iT, ipRef); } // T(K)
/* k(W/(m*K)) */	double thermal_conductivity(double iT, double iN, std::string iDop, reference *ipRef=NULL) { return mpMat->k(iT, iN, iDop, ipRef); } // T(K), N(1/m^3), Dop(-)
/* k(W/(m*K)) */	double thermal_conductivity(double iT, char iDir, reference *ipRef=NULL) { return mpMat->k(iT, iDir, ipRef); } // T(K), dir(-)
/* k(W/(m*K)) */	double thermal_conductivity(double iT, reference *ipRef=NULL) { return mpMat->k(iT, ipRef); } // T(K)
/* cp(J/(kg*K)) */	double specific_heat(double iT, reference *ipRef=NULL) { return mpMat->cp(iT, ipRef); } // T(K)
/* g(J/(kg*K)) */	double density(double iT, reference *ipRef=NULL) { return mpMat->g(iT, ipRef); } // T(K)
/* epsR(-) */		double dielectric_constant(reference *ipRef=NULL) { return mpMat->dc(ipRef); }
/* nR(-) */			double refractive_index(double iLam, double iT, double iN, std::string iDop, reference *ipRef=NULL) { return mpMat->nR(iLam, iT, iN, iDop, ipRef); } // Lam(nm), T(K), N(1/m^3), Dop(-)
/* nR(-) */			double refractive_index(double iLam, double iT, reference *ipRef=NULL) { return mpMat->nR(iLam, iT, ipRef); } // Lam(nm), T(K)
/* nR(-) */			double refractive_index(double iLam, reference *ipRef=NULL) { return mpMat->nR(iLam, ipRef); } // Lam(nm)
/* alfa(cm^-1) */	double absorption(double iLam, double iT, double iN, std::string iDop, reference *ipRef=NULL) { return mpMat->abs(iLam, iT, iN, iDop, ipRef); } // lam(nm), T(K), N(1/m^3), Dop(-)
/* alfa(cm^-1) */	double absorption(double iLam, double iT, reference *ipRef=NULL) { return mpMat->abs(iLam, iT, ipRef); } // lam(nm), T(K)
/* alfa(cm^-1) */	double absorption(double iLam, reference *ipRef=NULL) { return mpMat->abs(iLam, ipRef); } // lam(nm)

/* a(A) */			double a(double iT, reference *ipRef=NULL) {	return mpMat->a(iT, ipRef); } // T(K)
/* c(A) */			double c(double iT, reference *ipRef=NULL) {	return mpMat->c(iT, ipRef); } // T(K)
/* chi(eV) */		double ea(reference *ipRef=NULL) { return mpMat->ea(ipRef); };
/* Eg(eV) */		double Eg(double iT, char iPoint, reference *ipRef=NULL) { return mpMat->Eg(iT, iPoint, ipRef); } // T(K), point(-)
/* Eg(eV) */		double Eg(double iT, reference *ipRef=NULL) { return mpMat->Eg(iT, ipRef); } // T(K)
/* Dso(eV) */		double Dso(reference *ipRef=NULL) { return mpMat->Dso(ipRef); }
/* me(m0) */		double me(reference *ipRef=NULL) { return mpMat->me(ipRef); }
/* mhh(m0) */		double mhh(reference *ipRef=NULL) { return mpMat->mhh(ipRef); }
/* mlh(m0) */		double mlh(reference *ipRef=NULL) { return mpMat->mlh(ipRef); }
/* meL(m0) */		double meL(reference *ipRef=NULL) { return mpMat->meL(ipRef); }
/* meT(m0) */		double meT(reference *ipRef=NULL) { return mpMat->meT(ipRef); }
/* mhhL(m0) */		double mhhL(reference *ipRef=NULL) { return mpMat->mhhL(ipRef); }
/* mhhT(m0) */		double mhhT(reference *ipRef=NULL) { return mpMat->mhhT(ipRef); }
/* mlhL(m0) */		double mlhL(reference *ipRef=NULL) { return mpMat->mlhL(ipRef); }
/* mlhT(m0) */		double mlhT(reference *ipRef=NULL) { return mpMat->mlhT(ipRef); }
/* mso(m0) */		double mso(reference *ipRef=NULL) { return mpMat->mso(ipRef); }
/* mh(m0) */		double mh(reference *ipRef=NULL) { return mpMat->mh(ipRef); }
/* Ev(eV) */		double Ev(reference *ipRef=NULL) { return mpMat->Ev(ipRef); }
/* Ec(eV) */		double Ec(double iT, reference *ipRef=NULL) { return mpMat->Ec(iT, ipRef); } // T(K)
/* ac(eV) */		double ac(reference *ipRef=NULL) { return mpMat->ac(ipRef); }
/* av(eV) */		double av(reference *ipRef=NULL) { return mpMat->av(ipRef); }
/* b(eV) */			double b(reference *ipRef=NULL) { return mpMat->b(ipRef); }
/* d(eV) */			double d(reference *ipRef=NULL) { return mpMat->d(ipRef); }
/* c11(GPa) */		double c11(reference *ipRef=NULL) { return mpMat->c11(ipRef); }
/* c12(GPa) */		double c12(reference *ipRef=NULL) { return mpMat->c12(ipRef); }
/* c13(GPa) */		double c13(reference *ipRef=NULL) { return mpMat->c13(ipRef); }
/* c33(GPa) */		double c33(reference *ipRef=NULL) { return mpMat->c33(ipRef); }
/* c44(GPa) */		double c44(reference *ipRef=NULL) { return mpMat->c44(ipRef); }
/* d13(pm/V) */		double d13(reference *ipRef=NULL) { return mpMat->d13(ipRef); }
/* d15(pm/V) */		double d15(reference *ipRef=NULL) { return mpMat->d15(ipRef); }
/* d33(pm/V) */		double d33(reference *ipRef=NULL) { return mpMat->d33(ipRef); }
/* e15(C/m^2) */	double e15(reference *ipRef=NULL) { return mpMat->e15(ipRef); }
/* e31(C/m^2) */	double e31(reference *ipRef=NULL) { return mpMat->e31(ipRef); }
/* e33(C/m^2) */	double e33(reference *ipRef=NULL) { return mpMat->e33(ipRef); }
/* Psp(C/m^2) */	double Psp(reference *ipRef=NULL) { return mpMat->Psp(ipRef); }
/* Nc(1/m^3) */		double Nc(double iT, reference *ipRef=NULL) { return mpMat->Nc(iT, ipRef); } // T(K)
/* Nv(1/m^3) */		double Nv(double iT, reference *ipRef=NULL) { return mpMat->Nv(iT, ipRef); } // T(K)
/* ni(1/m^3) */		double ni(double iT, reference *ipRef=NULL) { return mpMat->ni(iT, ipRef); } // T(K)
/* Eact(eV) */		double Eact(std::string iDop, reference *ipRef=NULL) { return mpMat->Eact(iDop, ipRef); } // Dop(-)
/* Eact(eV) */		double Eact(double iN, std::string iDop, reference *ipRef=NULL) { return mpMat->Eact(iN, iDop, ipRef); } // N(1/m^3), Dop(-)
/* n(1/m^3) */		double n(double iT, double iN, std::string iDop, reference *ipRef=NULL) { return mpMat->n(iT, iN, iDop, ipRef); } // T(K), N(1/m^3), Dop(-)
/* mi(m^2/(V*s)) */	double mob(double iT, double iN, std::string iDop, reference *ipRef=NULL) { return mpMat->mob(iT, iN, iDop, ipRef); } // T(K), N(1/m^3), Dop(-)
/* sigma(S/m) */	double ec(double iT, double iN, std::string iDop, char iDir, reference *ipRef=NULL) { return mpMat->ec(iT, iN, iDop, iDir, ipRef); } // T(K), N(1/m^3), Dop(-), dir(-)
/* sigma(S/m) */	double ec(double iT, double iN, std::string iDop, reference *ipRef=NULL) { return mpMat->ec(iT, iN, iDop, ipRef); } // T(K), N(1/m^3), Dop(-)
/* sigma(S/m) */	double ec(double iT, reference *ipRef=NULL) { return mpMat->ec(iT, ipRef); } // T(K)
/* rho(Om*m) */		double er(double iT, reference *ipRef=NULL) { return mpMat->er(iT, ipRef); } // T(K)
/* k(W/(m*K)) */	double k(double iT, double iN, std::string iDop, reference *ipRef=NULL) { return mpMat->k(iT, iN, iDop, ipRef); } // T(K), N(1/m^3), Dop(-)
/* k(W/(m*K)) */	double k(double iT, char iDir, reference *ipRef=NULL) { return mpMat->k(iT, iDir, ipRef); } // T(K), dir(-)
/* k(W/(m*K)) */	double k(double iT, reference *ipRef=NULL) { return mpMat->k(iT, ipRef); } // T(K)
/* epsR(-) */		double dc(reference *ipRef=NULL) { return mpMat->dc(ipRef); }
/* cp(J/(kg*K)) */	double sh(double iT, reference *ipRef=NULL) { return mpMat->cp(iT, ipRef); } // T(K)
/* g(J/(kg*K)) */	double g(double iT, reference *ipRef=NULL) { return mpMat->g(iT, ipRef); } // T(K)
/* nR(-) */			double nR(double iLam, double iT, double iN, std::string iDop, reference *ipRef=NULL) { return mpMat->nR(iLam, iT, iN, iDop, ipRef); } // Lam(nm), T(K), N(1/m^3), Dop(-)
/* nR(-) */			double nR(double iLam, double iT, reference *ipRef=NULL) { return mpMat->nR(iLam, iT, ipRef); } // Lam(nm), T(K)
/* nR(-) */			double nR(double iLam, reference *ipRef=NULL) { return mpMat->nR(iLam, ipRef); } // Lam(nm)
/* alfa(cm^-1) */	double abs(double iLam, double iT, double iN, std::string iDop, reference *ipRef=NULL) { return mpMat->abs(iLam, iT, iN, iDop, ipRef); } // lam(nm), T(K), N(1/m^3), Dop(-)
/* alfa(cm^-1) */	double abs(double iLam, double iT, reference *ipRef=NULL) { return mpMat->abs(iLam, iT, ipRef); } // lam(nm), T(K)
/* alfa(cm^-1) */	double abs(double iLam, reference *ipRef=NULL) { return mpMat->abs(iLam, ipRef); } // lam(nm)

	void setInt(std::string iInt) { mpMat->setInt(iInt); } // wybor sposobu interpolacji

	material_interface(std::string iName);									// konstruktor dla zwiazkow podwojnych
	material_interface(std::string iName, double iX);						// konstruktor dla zwiazkow potrojnych i podwjnych (wtedy iX to grubosc warstwy)
	material_interface(std::string iName, double iX, double iY);			// konstruktor dla zwiazkow poczwornych
	material_interface(std::string iName, double iX, double iY, double iZ);	// konstruktor dla zwiazkow piecioskladnikowych
	material_interface();
	~material_interface();              
};

namespace cMD
{
	bool matInBase(std::string iMat, int &iInfo);
	double par(std::string iPar, std::string iMat, double iX, double iY, double iZ, double iN, std::string iDop, double iLam, double iT, char iDir, int &iInfo);
}

#endif
